@@ -25,7 +25,7 @@
   # needed for singularity check
   check_if_installed("performance", reason = "to check for singularity")
 
-  faminfo <- model_info(model, verbose = FALSE)
+  faminfo <- model_info(model, response = 1, verbose = FALSE)
 
   # check argument
   approx_method <- match.arg(approximation, c("lognormal", "delta", "trigamma", "observation_level"))
@@ -211,7 +211,6 @@
   }
 
 
-
   # if we only need residual variance, we can delete those
   # values again...
   if (component == "residual") {
@@ -234,7 +233,6 @@
 }
 
 
-
 # store essential information on coefficients, model matrix and so on
 # as list, since we need these information throughout the functions to
 # calculate the variance components...
@@ -508,7 +506,6 @@
 }
 
 
-
 # fixed effects variance ------------------------------------------------------
 #
 # This is in line with Nakagawa et al. 2017, Suppl. 2
@@ -522,7 +519,6 @@
 }
 
 
-
 # dispersion-specific variance ----
 # ---------------------------------
 .compute_variance_dispersion <- function(model, mixed_effects_info, faminfo, obs_terms) {
@@ -536,7 +532,6 @@
 }
 
 
-
 # variance associated with a random-effects term (Johnson 2014) --------------
 #
 # This is in line with Nakagawa et al. 2017, Suppl. 2, and package MuMIm
@@ -576,7 +571,6 @@
 }
 
 
-
 # distribution-specific (residual) variance (Nakagawa et al. 2017) ------------
 # (also call obersvation level variance).
 #
@@ -608,7 +602,10 @@
     # single sigma parameter. in this case, we can't calculate residual
     # variance and return NULL
     if (inherits(model, "brmsfit")) {
-      params <- find_parameters(model)$conditional
+      params <- unlist(
+        compact_list(find_parameters(model)[c("conditional", "sigma")]),
+        use.names = FALSE
+      )
       sigma_params <- grepl("b_sigma", params, fixed = TRUE)
       if (sum(sigma_params) > 1) {
         if (verbose) {
@@ -1028,7 +1025,6 @@
 }
 
 
-
 # Get distributional variance for poisson-family
 # ----------------------------------------------
 .variance_family_poisson <- function(model, mu, faminfo) {
@@ -1044,7 +1040,6 @@
 }
 
 
-
 # Get distributional variance for beta-family
 # ----------------------------------------------
 .variance_family_beta <- function(model, mu, phi) {
@@ -1056,7 +1051,6 @@
 }
 
 
-
 # Get distributional variance for ordered beta-family
 # ----------------------------------------------
 .variance_family_orderedbeta <- function(model, mu, phi) {
@@ -1068,7 +1062,6 @@
 }
 
 
-
 # Get distributional variance for beta-family
 # ----------------------------------------------
 .variance_family_betabinom <- function(model, mu, phi) {
@@ -1082,7 +1075,6 @@
 }
 
 
-
 # Get distributional variance for tweedie-family
 # ----------------------------------------------
 .variance_family_tweedie <- function(model, mu, phi) {
@@ -1097,7 +1089,6 @@
 }
 
 
-
 # Get distributional variance for nbinom-family
 # ----------------------------------------------
 .variance_family_nbinom <- function(model, mu, sig, faminfo) {
@@ -1123,7 +1114,6 @@
 }
 
 
-
 # For zero-inflated negative-binomial models,
 # the distributional variance is based on Zuur et al. 2012
 # ----------------------------------------------
@@ -1173,7 +1163,6 @@
 }
 
 
-
 # For zero-inflated poisson models, the
 # distributional variance is based on Zuur et al. 2012
 # ----------------------------------------------
@@ -1194,7 +1183,6 @@
 }
 
 
-
 # Get distribution-specific variance for general and
 # undefined families / link-functions
 # ----------------------------------------------
@@ -1226,9 +1214,6 @@
 }
 
 
-
-
-
 # return existence of random slopes ----
 # ----------------------------------------------
 .random_slopes_in_fixed <- function(model) {
@@ -1256,9 +1241,6 @@
 }
 
 
-
-
-
 # random intercept-variances, i.e.
 # between-subject-variance (tau 00) ----
 # ----------------------------------------------
@@ -1276,9 +1258,6 @@
 }
 
 
-
-
-
 # random slope-variances (tau 11) ----
 # ----------------------------------------------
 .random_slope_variance <- function(model, mixed_effects_info) {
@@ -1333,9 +1312,6 @@
 }
 
 
-
-
-
 # slope-intercept-correlations (rho 01) ----
 # ----------------------------------------------
 .random_slope_intercept_corr <- function(model, mixed_effects_info) {
@@ -1366,9 +1342,6 @@
 }
 
 
-
-
-
 # slope-slope-correlations (rho 01) ----
 # ----------------------------------------------
 .random_slopes_corr <- function(model, mixed_effects_info) {
@@ -1441,10 +1414,6 @@
 }
 
 
-
-
-
-
 # helper --------------------------
 
 .reshape_longer <- function(data,
