@@ -16,12 +16,17 @@
 #'   empty (i.e. filled with whitespaces).
 #' @param format Name of output-format, as string. If `NULL` (or `"text"`),
 #'   returned output is used for basic printing. Can be one of `NULL` (the
-#'   default) resp. `"text"` for plain text, `"markdown"` (or
-#'   `"md"`) for markdown and `"html"` for HTML output.
-#' @param title,caption,subtitle Table title (same as caption) and subtitle, as strings. If `NULL`,
-#'   no title or subtitle is printed, unless it is stored as attributes (`table_title`,
-#'   or its alias `table_caption`, and `table_subtitle`). If `x` is a list of
-#'   data frames, `caption` may be a list of table captions, one for each table.
+#'   default) resp. `"text"` for plain text, `"markdown"` (or `"md"`) for
+#'   markdown and `"html"` for HTML output. A special option is `"tt"`, which
+#'   creates a [`tinytable::tt()`] object, where the output format is dependent
+#'   on the context where the table is used, i.e. it can be markdown format when
+#'   `export_table()` is used in markdown files, or LaTex format when creating
+#'   PDFs etc.
+#' @param title,caption,subtitle Table title (same as caption) and subtitle, as
+#'   strings. If `NULL`, no title or subtitle is printed, unless it is stored as
+#'   attributes (`table_title`, or its alias `table_caption`, and
+#'   `table_subtitle`). If `x` is a list of data frames, `caption` may be a list
+#'   of table captions, one for each table.
 #' @param footer Table footer, as string. For markdown-formatted tables, table
 #'   footers, due to the limitation in markdown rendering, are actually just a
 #'   new text line under the table. If `x` is a list of data frames, `footer`
@@ -49,20 +54,25 @@
 #' @param table_width Numeric,`"auto"`, `NULL` or `Inf`, indicating the width of
 #'   the complete table.
 #'   - If `table_width = "auto"` (default) and the table is wider than the
-#'   current width (i.e. line length) of the console (or any other source for
-#'   textual output, like markdown files), the table is split into multiple
-#'   parts.
+#'     current width (i.e. line length) of the console (or any other source for
+#'     textual output, like markdown files), the table is split into multiple
+#'     parts.
 #'   - Else, if `table_width` is numeric and table rows are larger than
-#'   `table_width`, the table is split into multiple parts. For each new table,
-#'   the first column is repeated for better orientation.
+#'     `table_width`, the table is split into multiple parts. For each new table,
+#'     the first column is repeated for better orientation.
 #'   - Use `NULL` or `Inf` to turn off automatic splitting of the table.
 #'   - `options(easystats_table_width = <value>)` can be used to set a default
-#'   width for tables.
+#'     width for tables.
 #' @param remove_duplicates Logical, if `TRUE` and table is split into multiple
 #'   parts, duplicated ("empty") rows will be removed. If `FALSE`, empty rows
 #'   will be preserved. Only applies when `table_width` is *not* `NULL` (or
 #'   `Inf`) *and* table is split into multiple parts.
-#' @param ... Currently not used.
+#' @param column_names Character vector of names that will be used as column
+#'   names in the table. Must either be of same length as columns in the table,
+#'   or a named vector, where names (LHS) indicate old column names, and values
+#'   (RHS) are used as new column names.
+#' @param ... Arguments passed to [`tinytable::tt()`] and [`tinytable::style_tt()`]
+#'   when `format = "tt"`.
 #' @inheritParams format_value
 #' @inheritParams get_data
 #'
@@ -109,6 +119,10 @@
 #'   c("we can have multiple colors per line.", "blue")
 #' )
 #' export_table(x)
+#'
+#' # rename column names
+#' export_table(x, column_names = letters[1:5])
+#' export_table(x, column_names = c(Species = "a"))
 #' }
 #'
 #' # column-width
@@ -136,6 +150,7 @@ export_table <- function(x,
                          caption = title,
                          subtitle = NULL,
                          footer = NULL,
+                         column_names = NULL,
                          align = NULL,
                          by = NULL,
                          zap_small = FALSE,
@@ -212,6 +227,7 @@ export_table <- function(x,
       caption = caption,
       subtitle = subtitle,
       footer = footer,
+      column_names = column_names,
       align = align,
       group_by = by,
       zap_small = zap_small,
@@ -220,7 +236,8 @@ export_table <- function(x,
       indent_rows = indent_rows,
       table_width = table_width,
       remove_duplicated_lines = remove_duplicates,
-      verbose = verbose
+      verbose = verbose,
+      ...
     )
   } else if (is.list(x)) {
     # table from list of data frames -----------------------------------------
@@ -286,6 +303,7 @@ export_table <- function(x,
         caption = t_title,
         subtitle = attributes(i)$table_subtitle,
         footer = t_footer,
+        column_names = column_names,
         align = align,
         group_by = by,
         zap_small = zap_small,
@@ -294,7 +312,8 @@ export_table <- function(x,
         indent_rows = indent_rows,
         table_width = table_width,
         remove_duplicated_lines = remove_duplicates,
-        verbose = verbose
+        verbose = verbose,
+        ...
       )
     })
 
@@ -365,6 +384,7 @@ print.insight_table <- function(x, ...) {
                           caption = NULL,
                           subtitle = NULL,
                           footer = NULL,
+                          column_names = NULL,
                           align = NULL,
                           group_by = NULL,
                           zap_small = FALSE,
@@ -373,8 +393,12 @@ print.insight_table <- function(x, ...) {
                           indent_rows = NULL,
                           table_width = NULL,
                           remove_duplicated_lines = FALSE,
-                          verbose = TRUE) {
-  tabledata <- as.data.frame(x)
+                          verbose = TRUE,
+                          ...) {
+  table_data <- as.data.frame(x)
+
+  # rename columns?
+  table_data <- .new_column_names(table_data, column_names)
 
   # check width argument, for format value. cannot have
   # named vector of length > 1 here
@@ -385,8 +409,8 @@ print.insight_table <- function(x, ...) {
   }
 
   # round all numerics, and convert to character
-  col_names <- names(tabledata)
-  tabledata[] <- lapply(tabledata, function(i) {
+  col_names <- names(table_data)
+  table_data[] <- lapply(table_data, function(i) {
     if (is.numeric(i)) {
       out <- format_value(i,
         digits = digits, protect_integers = protect_integers,
@@ -399,14 +423,14 @@ print.insight_table <- function(x, ...) {
   })
 
   # add back column names
-  names(tabledata) <- col_names
-  tabledata[is.na(tabledata)] <- as.character(missing)
+  names(table_data) <- col_names
+  table_data[is.na(table_data)] <- as.character(missing)
 
 
   if (identical(format, "html")) {
     # html formatting starts here, needs less preparation of table matrix
     out <- .format_html_table(
-      tabledata,
+      table_data,
       caption = caption,
       subtitle = subtitle,
       footer = footer,
@@ -419,13 +443,13 @@ print.insight_table <- function(x, ...) {
     # text and markdown go here...
   } else {
     # Add colnames as first row to the data frame
-    tabledata <- rbind(colnames(tabledata), tabledata)
+    table_data <- rbind(colnames(table_data), table_data)
 
     # Initial alignment for complete data frame is right-alignment
-    aligned <- format(tabledata, justify = "right")
+    aligned <- format(table_data, justify = "right")
 
     # default alignment
-    col_align <- rep("right", ncol(tabledata))
+    col_align <- rep("right", ncol(table_data))
 
     # first row definitely right alignment, fixed width
     first_row <- as.character(aligned[1, ])
@@ -478,6 +502,19 @@ print.insight_table <- function(x, ...) {
         indent_groups = indent_groups,
         indent_rows = indent_rows
       )
+    } else if (format == "tt") {
+      # tiny table formatting...
+      out <- .format_tiny_table(
+        final,
+        x,
+        caption = caption,
+        subtitle = subtitle,
+        footer = footer,
+        align = align,
+        indent_groups = indent_groups,
+        indent_rows = indent_rows,
+        ...
+      )
     }
   }
 
@@ -850,6 +887,43 @@ print.insight_table <- function(x, ...) {
 
 # helper ----------------
 
+
+.new_column_names <- function(table_data, column_names) {
+  # new column names for the table?
+  if (!is.null(column_names)) {
+    # if we have no named vector, we assume that we have new names for each
+    # column in the table
+    if (is.null(names(column_names))) {
+      # error if length does not match number of columns
+      if (length(column_names) != ncol(table_data)) {
+        format_error("Number of names in `column_names` does not match number of columns in data frame.")
+      }
+      colnames(table_data) <- column_names
+    } else {
+      # if we have a named vector, all elements must be named
+      if (!all(nzchar(names(column_names)))) {
+        format_error("If `column_names` is a named vector, all elements must be named.")
+      }
+      # if we have a named vector, all names must be present in column names
+      if (!all(names(column_names) %in% colnames(table_data))) {
+        suggestion <- .misspelled_string(colnames(table_data), names(column_names))
+        msg <- "Not all names in `column_names` were found in column names of data frame."
+        if (is.null(suggestion$msg) || !length(suggestion$msg) || !nzchar(suggestion$msg)) {
+          msg <- paste(msg, "Please use one of the following names:", .to_string(colnames(table_data)))
+        } else {
+          msg <- paste(msg, suggestion$msg)
+        }
+        format_error(msg)
+      }
+      for (i in names(column_names)) {
+        colnames(table_data)[colnames(table_data) == i] <- column_names[i]
+      }
+    }
+  }
+  table_data
+}
+
+
 .paste_footers <- function(footer, rows) {
   if (.is_empty_string(footer)) {
     return(rows)
@@ -927,6 +1001,37 @@ print.insight_table <- function(x, ...) {
 }
 
 
+# markdown formatting -------------------
+
+.format_tiny_table <- function(final,
+                               x,
+                               caption = NULL,
+                               subtitle = NULL,
+                               footer = NULL,
+                               align = NULL,
+                               indent_groups = NULL,
+                               indent_rows = NULL,
+                               ...) {
+  # need data frame, not matrix
+  final <- as.data.frame(final)
+
+  if (!is.null(align) && length(align) == 1) {
+    align <- switch(align,
+      left = "l",
+      center = "c",
+      right = "r",
+      firstleft = paste0("l", rep_len("r", ncol(final) - 1)),
+      align
+    )
+  }
+
+  check_if_installed("tinytable")
+
+  out <- tinytable::tt(final, caption = caption, notes = footer, ...)
+  tinytable::style_tt(out, align = align, ...)
+}
+
+
 # markdown formatting -------------------
 
 .format_markdown_table <- function(final,
@@ -1072,6 +1177,9 @@ print.insight_table <- function(x, ...) {
     highlight_rows <- NULL
   }
 
+  # do we need to render <br>?
+  any_br <- any(vapply(final, function(i) any(grepl("<br>", i, fixed = TRUE)), logical(1)))
+  any_nbsp <- any(vapply(final, function(i) any(grepl("&nbsp;", i, fixed = TRUE)), logical(1)))
 
   # validation check - clean caption, subtitle and footer from ansi-colour codes,
   # which only work for text format... But if user occidentally provides colours
@@ -1147,5 +1255,10 @@ print.insight_table <- function(x, ...) {
     }
   }
 
+  # correctly render line breaks like <br>
+  if (any_br || any_nbsp) {
+    out <- gt::fmt_markdown(out)
+  }
+
   out
 }
