@@ -20,20 +20,19 @@
 #' - `conditional`, the "fixed effects" part from the model
 #' - `random`, the "random effects" part from the model
 #' - `zero_inflated`, the "fixed effects" part from the zero-inflation component
-#'   of the model
+#'   of the model. For **brms**, this is named `zi`.
 #' - `zero_inflated_random`, the "random effects" part from the zero-inflation
-#'   component of the model
+#'   component of the model. For **brms**, this is named `zi_random`.
 #' - `smooth_terms`, the smooth parameters
 #'
-#' Furthermore, some models, especially from **brms**, can also return auxiliary
-#' parameters. These may be one of the following:
+#' Furthermore, some models, especially from **brms**, can also return other
+#' auxiliary (distributional) parameters. These may be one of the following:
 #'
 #' - `sigma`, the residual standard deviation (auxiliary parameter)
 #' - `dispersion`, the dispersion parameters (auxiliary parameter)
 #' - `beta`, the beta parameter (auxiliary parameter)
-#' - `simplex`, simplex parameters of monotonic effects (**brms** only)
-#' - `mix`, mixture parameters (**brms** only)
-#' - `shiftprop`, shifted proportion parameters (**brms** only)
+#' - and any pre-defined or arbitrary distributional parameter for models from
+#'   package **brms**, like `mu`, `ndt`, `kappa`, etc.
 #'
 #' Models of class **BGGM** additionally can return the elements `correlation`
 #' and `intercept`.
@@ -200,193 +199,6 @@ find_parameters.bamlss <- function(x, flatten = FALSE, component = "all", parame
 }
 
 
-#' @rdname find_parameters.BGGM
-#' @export
-find_parameters.brmsfit <- function(x,
-                                    effects = "all",
-                                    component = "all",
-                                    flatten = FALSE,
-                                    parameters = NULL,
-                                    ...) {
-  effects <- validate_argument(effects, c("all", "fixed", "random"))
-  component <- validate_argument(component, c("all", .all_elements(), "location", "distributional"))
-
-  fe <- dimnames(x$fit)$parameters
-  # fe <- colnames(as.data.frame(x))
-
-  # remove redundant columns. These seem to be new since brms 2.16?
-  pattern <- "^[A-z]_\\d\\.\\d\\.(.*)"
-  fe <- fe[!grepl(pattern, fe)]
-
-  is_mv <- NULL
-
-  # remove "Intercept"
-  fe <- fe[!startsWith(fe, "Intercept")]
-
-  cond <- fe[grepl("^(b_|bs_|bsp_|bcs_)(?!zi_)(.*)", fe, perl = TRUE)]
-  zi <- fe[grepl("^(b_zi_|bs_zi_|bsp_zi_|bcs_zi_)", fe)]
-  rand <- fe[grepl("(?!.*__(zi|sigma|beta))(?=.*^r_)", fe, perl = TRUE) & !startsWith(fe, "prior_")]
-  randzi <- fe[grepl("^r_(.*__zi)", fe)]
-  rand_sd <- fe[grepl("(?!.*_zi)(?=.*^sd_)", fe, perl = TRUE)]
-  randzi_sd <- fe[grepl("^sd_(.*_zi)", fe)]
-  rand_cor <- fe[grepl("(?!.*_zi)(?=.*^cor_)", fe, perl = TRUE)]
-  randzi_cor <- fe[grepl("^cor_(.*_zi)", fe)]
-  simo <- fe[startsWith(fe, "simo_")]
-  car_struc <- fe[fe %in% c("car", "sdcar")]
-  smooth_terms <- fe[startsWith(fe, "sds_")]
-  priors <- fe[startsWith(fe, "prior_")]
-  sigma_param <- fe[startsWith(fe, "sigma_") | grepl("sigma", fe, fixed = TRUE)]
-  randsigma <- fe[grepl("^r_(.*__sigma)", fe)]
-  fixed_beta <- fe[grepl("beta", fe, fixed = TRUE)]
-  rand_beta <- fe[grepl("^r_(.*__beta)", fe)]
-  mix <- fe[grepl("mix", fe, fixed = TRUE)]
-  shiftprop <- fe[grepl("shiftprop", fe, fixed = TRUE)]
-  dispersion <- fe[grepl("dispersion", fe, fixed = TRUE)]
-  auxiliary <- fe[grepl("(shape|phi|precision|_ndt_)", fe)]
-
-  # if auxiliary is modelled directly, we need to remove duplicates here
-  # e.g. "b_sigma..." is in "cond" and in "sigma" now, we just need it in "cond".
-
-  sigma_param <- setdiff(sigma_param, c(cond, rand, rand_sd, rand_cor, randsigma, car_struc, "prior_sigma"))
-  fixed_beta <- setdiff(fixed_beta, c(cond, rand, rand_sd, rand_beta, rand_cor, car_struc))
-  auxiliary <- setdiff(auxiliary, c(cond, rand, rand_sd, rand_cor, car_struc))
-
-  l <- compact_list(list(
-    conditional = cond,
-    random = c(rand, rand_sd, rand_cor, car_struc),
-    zero_inflated = zi,
-    zero_inflated_random = c(randzi, randzi_sd, randzi_cor),
-    simplex = simo,
-    smooth_terms = smooth_terms,
-    sigma = sigma_param,
-    sigma_random = randsigma,
-    beta = fixed_beta,
-    beta_random = rand_beta,
-    dispersion = dispersion,
-    mix = mix,
-    shiftprop = shiftprop,
-    auxiliary = auxiliary,
-    priors = priors
-  ))
-
-  elements <- .get_elements(effects = effects, component = component)
-  elements <- c(elements, "priors")
-
-  if (is_multivariate(x)) {
-    rn <- names(find_response(x))
-    l <- lapply(rn, function(i) {
-      if (object_has_names(l, "conditional")) {
-        conditional <- l$conditional[grepl(sprintf("^(b_|bs_|bsp_|bcs_)\\Q%s\\E_", i), l$conditional)]
-      } else {
-        conditional <- NULL
-      }
-
-      if (object_has_names(l, "random")) {
-        random <- l$random[grepl(sprintf("__\\Q%s\\E\\[", i), l$random) |
-          grepl(sprintf("^sd_(.*)\\Q%s\\E\\_", i), l$random) |
-          startsWith(l$random, "cor_") |
-          l$random %in% c("car", "sdcar")]
-      } else {
-        random <- NULL
-      }
-
-      if (object_has_names(l, "zero_inflated")) {
-        zero_inflated <- l$zero_inflated[grepl(sprintf("^(b_zi_|bs_zi_|bsp_zi_|bcs_zi_)\\Q%s\\E_", i), l$zero_inflated)]
-      } else {
-        zero_inflated <- NULL
-      }
-
-      if (object_has_names(l, "zero_inflated_random")) {
-        zero_inflated_random <- l$zero_inflated_random[grepl(sprintf("__zi_\\Q%s\\E\\[", i), l$zero_inflated_random) |
-          grepl(sprintf("^sd_(.*)\\Q%s\\E\\_", i), l$zero_inflated_random) |
-          startsWith(l$zero_inflated_random, "cor_")]
-      } else {
-        zero_inflated_random <- NULL
-      }
-
-      if (object_has_names(l, "simplex")) {
-        simplex <- l$simplex
-      } else {
-        simplex <- NULL
-      }
-
-      if (object_has_names(l, "sigma")) {
-        sigma_param <- l$sigma[grepl(sprintf("^sigma_\\Q%s\\E$", i), l$sigma)]
-      } else {
-        sigma_param <- NULL
-      }
-
-      if (object_has_names(l, "beta")) {
-        fixed_beta <- l$beta[grepl(sprintf("^beta_\\Q%s\\E$", i), l$beta)]
-      } else {
-        fixed_beta <- NULL
-      }
-
-      if (object_has_names(l, "dispersion")) {
-        dispersion <- l$dispersion[grepl(sprintf("^dispersion_\\Q%s\\E$", i), l$dispersion)]
-      } else {
-        dispersion <- NULL
-      }
-
-      if (object_has_names(l, "mix")) {
-        mix <- l$mix[grepl(sprintf("^mix_\\Q%s\\E$", i), l$mix)]
-      } else {
-        mix <- NULL
-      }
-
-      if (object_has_names(l, "shape") || object_has_names(l, "precision")) {
-        aux <- l$aux[grepl(sprintf("^(shape|precision)_\\Q%s\\E$", i), l$aux)]
-      } else {
-        aux <- NULL
-      }
-
-      if (object_has_names(l, "smooth_terms")) {
-        smooth_terms <- l$smooth_terms
-      } else {
-        smooth_terms <- NULL
-      }
-
-      if (object_has_names(l, "priors")) {
-        priors <- l$priors
-      } else {
-        priors <- NULL
-      }
-
-      pars <- compact_list(list(
-        conditional = conditional,
-        random = random,
-        zero_inflated = zero_inflated,
-        zero_inflated_random = zero_inflated_random,
-        simplex = simplex,
-        smooth_terms = smooth_terms,
-        sigma = sigma_param,
-        beta = fixed_beta,
-        dispersion = dispersion,
-        mix = mix,
-        priors = priors,
-        auxiliary = aux
-      ))
-
-      compact_list(pars[elements])
-    })
-
-    names(l) <- rn
-    is_mv <- "1"
-  } else {
-    l <- compact_list(l[elements])
-  }
-
-  l <- .filter_pars(l, parameters, !is.null(is_mv) && is_mv == "1")
-  attr(l, "is_mv") <- is_mv
-
-  if (flatten) {
-    unique(unlist(l, use.names = FALSE))
-  } else {
-    l
-  }
-}
-
-
 #' @export
 find_parameters.bayesx <- function(x, component = "all", flatten = FALSE, parameters = NULL, ...) {
   cond <- rownames(stats::coef(x))
@@ -551,7 +363,6 @@ find_parameters.stanmvreg <- function(x,
 }
 
 
-
 # Simulation models -----------------------------
 
 
