@@ -49,6 +49,24 @@ find_response.default <- function(x, combine = TRUE, ...) {
 }
 
 
+#' @export
+find_response.insight_formula <- function(x, combine = TRUE, ...) {
+  if (is.null(x)) {
+    return(NULL)
+  }
+
+  # this is for multivariate response models,
+  # where we have a list of formulas
+  if (is_multivariate(x)) {
+    resp <- unlist(lapply(x, function(i) safe_deparse(i$conditional[[2L]])))
+  } else {
+    resp <- safe_deparse(x$conditional[[2L]])
+  }
+
+  check_cbind(resp, combine, model = NULL)
+}
+
+
 #' @export
 find_response.brmsfit <- function(x, combine = TRUE, ...) {
   f <- find_formula(x, verbose = FALSE)
@@ -124,10 +142,29 @@ find_response.mediate <- function(x, combine = TRUE, ...) {
 }
 
 
-#' @rdname find_response
 #' @export
-find_response.mjoint <- function(x, combine = TRUE, component = c("conditional", "survival", "all"), ...) {
-  component <- match.arg(component)
+find_response.tune_results <- function(x, combine = TRUE, ...) {
+  att <- attributes(x)
+  if (any(names(att) == "outcomes")) {
+    resp <- att$outcomes
+  } else {
+    return(NULL)
+  }
+  check_cbind(resp, combine, model = x)
+}
+
+
+#' @export
+find_response.workflow <- function(x, combine = TRUE, ...) {
+  insight::check_if_installed("tune")
+  resp <- tune::outcome_names(x)
+  check_cbind(resp, combine, model = x)
+}
+
+
+#' @export
+find_response.mjoint <- function(x, combine = TRUE, component = "conditional", ...) {
+  component <- validate_argument(component, c("conditional", "survival", "all"))
   f <- find_formula(x, verbose = FALSE)
 
   if (is.null(f)) {
@@ -149,11 +186,8 @@ find_response.mjoint <- function(x, combine = TRUE, component = c("conditional",
 
 #' @rdname find_response
 #' @export
-find_response.joint <- function(x,
-                                combine = TRUE,
-                                component = c("conditional", "survival", "all"),
-                                ...) {
-  component <- match.arg(component)
+find_response.joint <- function(x, combine = TRUE, component = "conditional", ...) {
+  component <- validate_argument(component, c("conditional", "survival", "all"))
   f <- find_formula(x, verbose = FALSE)
 
   if (is.null(f)) {
