@@ -66,10 +66,10 @@ get_data <- function(x, ...) {
   }
 
   # handle arguments
-  effects <- match.arg(effects, choices = c("all", "fixed", "random"))
-  component <- match.arg(
+  effects <- validate_argument(effects, c("all", "fixed", "random"))
+  component <- validate_argument(
     component,
-    choices = c("all", "conditional", "zero_inflated", "zi", "smooth_terms", "dispersion")
+    c("all", "conditional", "zero_inflated", "zi", "smooth_terms", "dispersion")
   )
 
   # we want to add the variable for subsettig, too
@@ -276,7 +276,6 @@ get_data <- function(x, ...) {
 }
 
 
-
 # default method ------------------------------------------------------
 
 #' @rdname get_data
@@ -360,7 +359,6 @@ get_data.mhurdle <- function(x, verbose = TRUE, ...) {
 }
 
 
-
 # classical and survival models -----------------------------------------------
 
 
@@ -704,6 +702,8 @@ get_data.glmmTMB <- function(x,
   mf <- .add_zeroinf_data(x, mf, model.terms$dispersion)
   mf <- .add_zeroinf_data(x, mf, model.terms$zero_inflated)
   mf <- .add_zeroinf_data(x, mf, model.terms$zero_inflated_random)
+  mf <- .add_zeroinf_data(x, mf, model.terms$zi)
+  mf <- .add_zeroinf_data(x, mf, model.terms$zi_random)
   .return_combined_data(x, mf, effects, component, model.terms, verbose = verbose)
 }
 
@@ -876,7 +876,6 @@ get_data.glmm <- function(x,
 }
 
 
-
 #' @export
 get_data.mixor <- function(x,
                            effects = "all",
@@ -948,7 +947,6 @@ get_data.glmmadmb <- function(x,
 }
 
 
-
 #' @export
 get_data.rlmerMod <- function(x, effects = "all", source = "environment", verbose = TRUE, ...) {
   # try to recover data from environment
@@ -1081,8 +1079,11 @@ get_data.MixMod <- function(x,
   }
 
   # fall back to extract data from model frame
-  effects <- match.arg(effects, choices = c("all", "fixed", "random"))
-  component <- match.arg(component, choices = c("all", "conditional", "zi", "zero_inflated", "dispersion"))
+  effects <- validate_argument(effects, c("all", "fixed", "random"))
+  component <- validate_argument(
+    component,
+    c("all", "conditional", "zi", "zero_inflated", "dispersion")
+  )
 
   tryCatch(
     {
@@ -1543,9 +1544,6 @@ get_data.bife <- function(x, effects = "all", source = "environment", verbose =
 }
 
 
-
-
-
 # Bayesian regression ---------------------------------------------------
 
 
@@ -1735,7 +1733,6 @@ get_data.probitmfx <- get_data.betamfx
 get_data.negbinmfx <- get_data.betamfx
 
 
-
 # other models ------------------------------------------------------
 
 
