@@ -46,7 +46,6 @@ get_parameters <- function(x, ...) {
 }
 
 
-
 # Default models ---------------------------------------------
 
 
@@ -109,8 +108,6 @@ get_parameters.data.frame <- function(x, ...) {
 }
 
 
-
-
 # Special models ---------------------------------------------
 
 
@@ -308,8 +305,8 @@ get_parameters.mipo <- function(x, ...) {
     stringsAsFactors = FALSE
   )
   # check for ordinal-alike models
-  if ("y.level" %in% colnames(s)) {
-    out$Response <- as.vector(s$y.level)
+  if (!is.null(x$pooled) && "y.level" %in% colnames(x$pooled)) {
+    out$Response <- as.vector(x$pooled$y.level)
   }
   text_remove_backticks(out)
 }
@@ -379,7 +376,6 @@ get_parameters.mle2 <- function(x, ...) {
 get_parameters.mle <- get_parameters.mle2
 
 
-
 #' @export
 get_parameters.lrm <- function(x, ...) {
   tryCatch(
@@ -485,7 +481,6 @@ get_parameters.mclogit <- function(x, ...) {
 }
 
 
-
 #' @export
 get_parameters.mlm <- function(x, ...) {
   cs <- stats::coef(summary(x))
@@ -521,7 +516,6 @@ get_parameters.gbm <- function(x, ...) {
 }
 
 
-
 #' @export
 get_parameters.BBreg <- function(x, ...) {
   pars <- summary(x)$coefficients
@@ -604,10 +598,6 @@ get_parameters.metaplus <- function(x, ...) {
 }
 
 
-
-
-
-
 # SEM models ---------------------------------------------
 
 
@@ -654,7 +644,6 @@ get_parameters.blavaan <- function(x, summary = FALSE, standardize = FALSE, ...)
 }
 
 
-
 #' @export
 get_parameters.lavaan <- function(x, standardize = FALSE, ...) {
   check_if_installed("lavaan")
@@ -684,8 +673,6 @@ get_parameters.lavaan <- function(x, standardize = FALSE, ...) {
 }
 
 
-
-
 # Ordinal models ---------------------------------------------
 
 
@@ -720,13 +707,6 @@ get_parameters.bracl <- function(x, ...) {
 }
 
 
-
-
-
-
-
-
-
 # Anova and Standard models --------------------------------------------------
 
 
@@ -745,7 +725,6 @@ get_parameters.aov <- function(x, ...) {
 }
 
 
-
 #' @export
 get_parameters.aovlist <- function(x, ...) {
   cs <- stats::coef(x)
@@ -763,7 +742,6 @@ get_parameters.aovlist <- function(x, ...) {
 }
 
 
-
 #' @export
 get_parameters.manova <- function(x, ...) {
   params <- stats::na.omit(stats::coef(x))
@@ -783,7 +761,6 @@ get_parameters.manova <- function(x, ...) {
 get_parameters.maov <- get_parameters.manova
 
 
-
 #' @export
 get_parameters.afex_aov <- function(x, ...) {
   if (is.null(x$aov)) {
@@ -795,8 +772,8 @@ get_parameters.afex_aov <- function(x, ...) {
 
 
 #' @export
-get_parameters.pgmm <- function(x, component = c("conditional", "all"), ...) {
-  component <- match.arg(component)
+get_parameters.pgmm <- function(x, component = "conditional", ...) {
+  component <- validate_argument(component, c("conditional", "all"))
   cs <- stats::coef(summary(x, time.dummies = TRUE, robust = FALSE))
   params <- data.frame(
     Parameter = rownames(cs),
@@ -817,8 +794,6 @@ get_parameters.pgmm <- function(x, component = c("conditional", "all"), ...) {
 }
 
 
-
-
 # utility functions ---------------------------------
 
 
@@ -828,7 +803,6 @@ get_parameters.pgmm <- function(x, component = c("conditional", "all"), ...) {
 }
 
 
-
 .get_armsim_ranef_parms <- function(x) {
   dat <- NULL
   if (methods::.hasSlot(x, "ranef")) {
