@@ -274,7 +274,7 @@ get_predicted.default <- function(x,
   if (is.null(predictions)) {
     out <- NULL
   } else {
-    out <- .get_predicted_transform(x, predictions, my_args = my_args, ci_data, verbose = verbose)
+    out <- .get_predicted_transform(x, predictions, my_args = my_args, ci_data, verbose = verbose, ...)
   }
 
   # 4. step: final preparation
@@ -360,7 +360,7 @@ get_predicted.lm <- function(x,
   )
 
   # 3. step: back-transform
-  out <- .get_predicted_transform(x, predictions, my_args, ci_data, verbose = verbose)
+  out <- .get_predicted_transform(x, predictions, my_args, ci_data, verbose = verbose, ...)
 
   # 4. step: final preparation
   .get_predicted_out(out$predictions, my_args = my_args, ci_data = out$ci_data)
@@ -692,7 +692,7 @@ get_predicted.phylolm <- function(x,
   if (isTRUE(my_args$transform)) {
     # retrieve link-inverse, for back transformation...
     if (is.null(link_inv)) {
-      link_inv <- link_inverse(x)
+      link_inv <- .link_inverse(model = x, verbose = verbose, ...)
     }
 
     if (!is.null(ci_data)) {
@@ -730,7 +730,7 @@ get_predicted.phylolm <- function(x,
     }
 
     # Transform to response "type"
-    if (my_args$predict == "classification" && model_info(x, verbose = FALSE)$is_binomial) {
+    if (my_args$predict == "classification" && model_info(x, response = 1, verbose = FALSE)$is_binomial) {
       response <- get_response(x, as_proportion = TRUE)
       ci_data[!se_col] <- lapply(ci_data[!se_col], .get_predict_transform_response, response = response)
       predictions <- .get_predict_transform_response(predictions, response = response)
@@ -750,6 +750,89 @@ get_predicted.phylolm <- function(x,
 }
 
 
+# internal to return possibly bias correct link-function
+.link_inverse <- function(model = NULL,
+                          bias_correction = FALSE,
+                          sigma = NULL,
+                          verbose = TRUE,
+                          ...) {
+  if (isTRUE(bias_correction)) {
+    dots <- list(...)
+    if (!is.null(sigma) && !is.na(sigma)) {
+      residual_variance <- sigma^2
+    } else {
+      residual_variance <- NULL
+    }
+    l <- .bias_correction(model, residual_variance, verbose)$linkinv
+    if (is.null(l)) {
+      l <- link_inverse(model)
+    }
+  } else {
+    l <- link_inverse(model)
+  }
+  l
+}
+
+
+# apply bias-correction for back-transformation of predictions on the link-scale
+# we want sigma^2 (residual_variance) here to calculate the correction
+.bias_correction <- function(model = NULL, residual_variance = NULL, verbose = TRUE) {
+  # we need a model object
+  if (is.null(model)) {
+    return(NULL)
+  }
+  # extract residual variance, if not provided
+  if (is.null(residual_variance)) {
+    residual_variance <- .get_residual_variance(model) # returns sigma^2
+  }
+  # we need residual variance
+  if (is.null(residual_variance)) {
+    if (verbose) {
+      format_alert("Could not extract residual variance to apply bias correction. No bias adjustment carried out.") # nolint
+    }
+    return(NULL)
+  }
+
+  # extract current link function
+  link <- .safe(get_family(model))
+  # we need a link function
+  if (is.null(link)) {
+    if (verbose) {
+      format_alert("Could not extract information about the model's link-function to apply bias correction. No bias adjustment carried out.") # nolint
+    }
+    return(NULL)
+  }
+
+  link$inv <- link$linkinv
+  link$der <- link$mu.eta
+  link$residual_variance <- residual_variance / 2
+
+  link$der2 <- function(eta) {
+    with(link, 1000 * (der(eta + 5e-4) - der(eta - 5e-4)))
+  }
+  link$linkinv <- function(eta) {
+    with(link, inv(eta) + residual_variance * der2(eta))
+  }
+  link$mu.eta <- function(eta) {
+    with(link, der(eta) + 1000 * residual_variance * (der2(eta + 5e-4) - der2(eta - 5e-4)))
+  }
+  link
+}
+
+
+.get_residual_variance <- function(x) {
+  if (is_mixed_model(x)) {
+    out <- .safe(get_variance_residual(x))
+  } else {
+    out <- .safe(.get_sigma(x, no_recursion = TRUE, verbose = FALSE)^2, 0)
+    if (!length(out)) {
+      out <- 0
+    }
+  }
+  out
+}
+
+
 # -------------------------------------------------------------------------
 
 .get_predicted_out <- function(predictions, my_args = NULL, ci_data = NULL, ...) {
@@ -775,12 +858,18 @@ get_predicted.phylolm <- function(x,
         predictions <- cbind(predictions, my_args$data[focal_predictors])
       }
     }
+    # we have "Component" instead of "Response" for Wiener models
+    if ("Component" %in% colnames(predictions)) {
+      time_var <- "Component"
+    } else {
+      time_var <- "Response"
+    }
     predictions <- stats::reshape(predictions,
       direction = "long",
       varying = vary,
       times = vary,
       v.names = "Predicted",
-      timevar = "Response",
+      timevar = time_var,
       idvar = "Row"
     )
     row.names(predictions) <- NULL
@@ -839,6 +928,8 @@ get_predicted.phylolm <- function(x,
                                                  iter,
                                                  centrality_function = base::mean,
                                                  datagrid = NULL,
+                                                 is_wiener = FALSE,
+                                                 is_rtchoice = FALSE,
                                                  ...) {
   # outcome: ordinal/multinomial/multivariate produce a 3D array of predictions,
   # which we stack in "long" format
@@ -850,10 +941,17 @@ get_predicted.phylolm <- function(x,
       # rows repeated for each response level
       Row = rep(seq_len(ncol(iter)), times = dim(iter)[3]),
       # response levels repeated for each row
-      Response = rep(dimnames(iter)[[3]], each = dim(iter)[2]),
+      .Response_dummy = rep(dimnames(iter)[[3]], each = dim(iter)[2]),
       Predicted = apply(iter_stacked, 1, centrality_function),
       stringsAsFactors = FALSE
     )
+    # make sure we have the correct name for the "Response column"
+    if (is_wiener || is_rtchoice) {
+      new_name <- "Component"
+    } else {
+      new_name <- "Response"
+    }
+    names(predictions)[names(predictions) == ".Response_dummy"] <- new_name
     # for ordinal etc. outcomes, we need to include the data from the grid, too
     if (!is.null(datagrid)) {
       # due to reshaping predictions into long format, we to repeat the
