@@ -13,13 +13,12 @@
 #' @param ... One or more objects (data frames), which contain information about
 #'   the model parameters and related statistics (like confidence intervals, HDI,
 #'   ROPE, ...).
-#' @param split_by `split_by` should be a character vector with one or
-#'   more of the following elements: `"Effects"`, `"Component"`,
-#'   `"Response"` and `"Group"`. These are the column names returned
-#'   by [clean_parameters()], which is used to extract the information
-#'   from which the group or component model parameters belong. If `NULL`, the
-#'   merged data frame is returned. Else, the data frame is split into a list,
-#'   split by the values from those columns defined in `split_by`.
+#' @param by `by` should be a character vector with one or more of the following
+#' elements: `"Effects"`, `"Component"`, `"Response"` and `"Group"`. These are
+#' the column names returned by [clean_parameters()], which is used to extract
+#' the information from which the group or component model parameters belong.
+#' If `NULL`, the merged data frame is returned. Else, the data frame is split
+#' into a list, split by the values from those columns defined in `by`.
 #' @param format Name of output-format, as string. If `NULL` (or `"text"`),
 #'   assumed use for output is basic printing. If `"markdown"`, markdown-format
 #'   is assumed. This only affects the style of title- and table-caption
@@ -47,7 +46,7 @@
 #'
 #' @return
 #'
-#' A data frame or a list of data frames (if `split_by` is not `NULL`). If a
+#' A data frame or a list of data frames (if `by` is not `NULL`). If a
 #' list is returned, the element names reflect the model components where the
 #' extracted information in the data frames belong to, e.g.
 #' `random.zero_inflated.Intercept: persons`. This is the data frame that
@@ -91,7 +90,7 @@
 #' tmp <- as.data.frame(x)[, 1:4]
 #' tmp
 #'
-#' # Based on the "split_by" argument, we get a list of data frames that
+#' # Based on the "by" argument, we get a list of data frames that
 #' # is split into several parts that reflect the model components.
 #' print_parameters(model, tmp)
 #'
@@ -104,7 +103,7 @@
 #' @export
 print_parameters <- function(x,
                              ...,
-                             split_by = c("Effects", "Component", "Group", "Response"),
+                             by = c("Effects", "Component", "Group", "Response"),
                              format = "text",
                              parameter_column = "Parameter",
                              keep_parameter_column = TRUE,
@@ -122,10 +121,10 @@ print_parameters <- function(x,
   att <- att[!duplicated(names(att))]
 
   # get cleaned parameters
-  cp <- if (!inherits(x, "clean_parameters")) {
-    clean_parameters(x)
+  if (inherits(x, "clean_parameters")) {
+    cp <- x
   } else {
-    x
+    cp <- clean_parameters(x)
   }
 
   # merge all objects together
@@ -147,19 +146,20 @@ print_parameters <- function(x,
   )
 
   # return merged data frame if no splitting requested
-  if (is_empty_object(split_by)) {
+  if (is_empty_object(by)) {
     return(obj)
   }
 
   # determine where to split data frames
-  split_by <- split_by[split_by %in% colnames(obj)]
-  f <- lapply(split_by, function(i) {
-    if (i %in% colnames(obj)) obj[[i]]
+  by <- by[by %in% colnames(obj)]
+
+  # convert to factor, to preserve correct order
+  obj[by] <- lapply(obj[by], function(i) {
+    factor(i, levels = unique(i))
   })
-  names(f) <- split_by
 
   # split into groups, remove empty elements
-  out <- split(obj, f)
+  out <- split(obj, obj[by])
   out <- compact_list(lapply(out, function(i) {
     if (nrow(i) > 0L) i
   }))
@@ -167,7 +167,7 @@ print_parameters <- function(x,
   # remove trailing dots
   names(out) <- list_names <- gsub("(.*)\\.$", "\\1", names(out))
 
-  has_zeroinf <- any(grepl("zero_inflated", names(out), fixed = TRUE))
+  has_zeroinf <- any(grepl("(zero_inflated|zi)", names(out)))
 
   # create title attributes, and remove unnecessary columns from output
   out <- lapply(names(out), function(i) {
@@ -186,21 +186,22 @@ print_parameters <- function(x,
     for (j in seq_along(parts)) {
       # Rename "fixed", "random" etc. into proper titles. Here we have the
       # "Main title" of a subcomponent (like "Random effects")
-      if (parts[j] %in% c("fixed", "random") || (has_zeroinf && parts[j] %in% c("conditional", "zero_inflated"))) {
+      if (parts[j] %in% c("fixed", "random") || (has_zeroinf && parts[j] %in% c("conditional", "zi", "zero_inflated"))) {
         tmp <- switch(parts[j],
           fixed = "Fixed effects",
           random = "Random effects",
           dispersion = "Dispersion",
           conditional = "(conditional)",
+          zi = ,
           zero_inflated = "(zero-inflated)"
         )
         title1 <- paste0(title1, " ", tmp)
-      } else if (!parts[j] %in% c("conditional", "zero_inflated")) {
+      } else if (!parts[j] %in% c("conditional", "zi", "zero_inflated")) {
         # here we have the "subtitles" of a subcomponent
         # (like "Intercept: Group-Level 1")
         tmp <- switch(parts[j],
           simplex = "(monotonic effects)",
-          parts[j]
+          paste0("(", parts[j], ")")
         )
         title2 <- paste0(title2, " ", tmp)
       }
@@ -213,7 +214,7 @@ print_parameters <- function(x,
     # we don't need "Effects" and "Component" column any more, and probably
     # also no longer the "Group" column
     columns_to_remove <- c("Effects", "Component", "Cleaned_Parameter")
-    if (n_unique(.group) == 1) {
+    if (has_single_value(.group, remove_na = TRUE)) {
       columns_to_remove <- c(columns_to_remove, "Group")
     } else {
       .group <- NULL
@@ -237,7 +238,7 @@ print_parameters <- function(x,
     # remove empty columns
     if (isTRUE(remove_empty_column)) {
       for (j in colnames(element)) {
-        if (all(is.na(element[[j]])) || (is.character(element[[j]]) && all(element[[j]] == ""))) {
+        if (all(is.na(element[[j]])) || (is.character(element[[j]]) && all(element[[j]] == ""))) { # nolint
           element[[j]] <- NULL
         }
       }
