@@ -8,6 +8,7 @@
                          dispersion = FALSE,
                          verbose = TRUE,
                          glmmtmb_zeroinf = FALSE, # needed for edge cases
+                         brms_custom_name = NULL, # needed for edge cases
                          ...) {
   dots <- list(...)
   if (isTRUE(dots$return_family_only)) {
@@ -28,7 +29,7 @@
   # poisson family --------
 
   poisson_fam <-
-    fitfam %in% c("poisson", "quasipoisson", "genpois", "ziplss") |
+    fitfam %in% c("poisson", "quasipoisson", "genpois", "ziplss", "bell") |
       grepl("poisson", fitfam_lower, fixed = TRUE)
 
 
@@ -345,7 +346,7 @@
     dirichlet_fam || is.ordinal || zero.inf || is.censored || is.survival || is_binomtest ||
     is.categorical || hurdle || is.multinomial || is_chi2test || is_proptest || is_xtab) {
     linear_model <- FALSE
-  } else if (!(fitfam %in% c("Student's-t", "t Family", "gaussian", "Gaussian", "lognormal")) && !grepl("(\\st)$", fitfam)) {
+  } else if (!(fitfam %in% c("Student's-t", "t Family", "gaussian", "Gaussian", "lognormal", "skewnormal")) && !grepl("(\\st)$", fitfam)) {
     linear_model <- FALSE
   }
   if (!linear_model && is.survival && fitfam == "gaussian") {
@@ -418,6 +419,8 @@
     is_binomtest = is_binomtest,
     is_ftest = is_ftest,
     is_meta = is_meta,
+    is_wiener = inherits(x, "brmsfit") && fitfam == "wiener",
+    is_rtchoice = inherits(x, "brmsfit") && fitfam == "custom" && identical(brms_custom_name, "lnr"),
     link_function = link.fun,
     family = fitfam,
     n_obs = n_obs(x),
