@@ -1,4 +1,5 @@
 skip_on_cran()
+skip_if_not_installed("curl")
 skip_if_offline()
 skip_on_os("mac")
 skip_if_not_installed("brms")
@@ -150,12 +151,12 @@ test_that("find_predictors", {
     find_predictors(m4),
     list(
       conditional = c("child", "camper"),
-      zero_inflated = c("child", "camper")
+      zi = c("child", "camper")
     )
   )
   expect_identical(
     find_predictors(m4, effects = "random"),
-    list(random = "persons", zero_inflated_random = "persons")
+    list(random = "persons", zi_random = "persons")
   )
   expect_identical(find_predictors(m4, flatten = TRUE), c("child", "camper"))
 
@@ -164,11 +165,11 @@ test_that("find_predictors", {
     list(
       count = list(
         conditional = c("child", "camper"),
-        zero_inflated = "camper"
+        zi = "camper"
       ),
       count2 = list(
         conditional = c("child", "livebait"),
-        zero_inflated = "child"
+        zi = "child"
       )
     )
   )
@@ -266,8 +267,8 @@ test_that("find_variables", {
       response = "count",
       conditional = c("child", "camper"),
       random = "persons",
-      zero_inflated = c("child", "camper"),
-      zero_inflated_random = "persons"
+      zi = c("child", "camper"),
+      zi_random = "persons"
     )
   )
 
@@ -290,11 +291,11 @@ test_that("find_random", {
   expect_identical(find_random(m5), list(
     count = list(
       random = "persons",
-      zero_inflated_random = "persons"
+      zi_random = "persons"
     ),
     count2 = list(
       random = "persons",
-      zero_inflated_random = "persons"
+      zi_random = "persons"
     )
   ))
   expect_identical(find_random(m5, flatten = TRUE), "persons")
@@ -362,8 +363,8 @@ test_that("find_paramaters", {
     list(
       conditional = c("b_Intercept", "b_child", "b_camper"),
       random = c(sprintf("r_persons[%i,Intercept]", 1:4), "sd_persons__Intercept"),
-      zero_inflated = c("b_zi_Intercept", "b_zi_child", "b_zi_camper"),
-      zero_inflated_random = c(sprintf("r_persons__zi[%i,Intercept]", 1:4), "sd_persons__zi_Intercept")
+      zi = c("b_zi_Intercept", "b_zi_child", "b_zi_camper"),
+      zi_random = c(sprintf("r_persons__zi[%i,Intercept]", 1:4), "sd_persons__zi_Intercept")
     )
   )
 
@@ -374,8 +375,8 @@ test_that("find_paramaters", {
         count = list(
           conditional = c("b_count_Intercept", "b_count_child", "b_count_camper"),
           random = c(sprintf("r_persons__count[%i,Intercept]", 1:4), "sd_persons__count_Intercept"),
-          zero_inflated = c("b_zi_count_Intercept", "b_zi_count_camper"),
-          zero_inflated_random = c(sprintf("r_persons__zi_count[%i,Intercept]", 1:4), "sd_persons__zi_count_Intercept")
+          zi = c("b_zi_count_Intercept", "b_zi_count_camper"),
+          zi_random = c(sprintf("r_persons__zi_count[%i,Intercept]", 1:4), "sd_persons__zi_count_Intercept")
         ),
         count2 = list(
           conditional = c(
@@ -384,8 +385,8 @@ test_that("find_paramaters", {
             "b_count2_livebait"
           ),
           random = c(sprintf("r_persons__count2[%i,Intercept]", 1:4), "sd_persons__count2_Intercept"),
-          zero_inflated = c("b_zi_count2_Intercept", "b_zi_count2_child"),
-          zero_inflated_random = c(
+          zi = c("b_zi_count2_Intercept", "b_zi_count2_child"),
+          zi_random = c(
             sprintf("r_persons__zi_count2[%i,Intercept]", 1:4),
             "sd_persons__zi_count2_Intercept"
           )
@@ -396,7 +397,7 @@ test_that("find_paramaters", {
   )
 })
 
-test_that("find_paramaters", {
+test_that("get_paramaters", {
   expect_identical(
     colnames(get_parameters(m4)),
     c(
@@ -575,103 +576,34 @@ test_that("Issue #645", {
 test_that("clean_parameters", {
   expect_equal(
     clean_parameters(m4),
-    structure(
-      list(
-        Parameter = c(
-          "b_Intercept",
-          "b_child",
-          "b_camper",
-          "r_persons[1,Intercept]",
-          "r_persons[2,Intercept]",
-          "r_persons[3,Intercept]",
-          "r_persons[4,Intercept]",
-          "sd_persons__Intercept",
-          "b_zi_Intercept",
-          "b_zi_child",
-          "b_zi_camper",
-          "r_persons__zi[1,Intercept]",
-          "r_persons__zi[2,Intercept]",
-          "r_persons__zi[3,Intercept]",
-          "r_persons__zi[4,Intercept]",
-          "sd_persons__zi_Intercept"
-        ),
-        Effects = c(
-          "fixed",
-          "fixed",
-          "fixed",
-          "random",
-          "random",
-          "random",
-          "random",
-          "random",
-          "fixed",
-          "fixed",
-          "fixed",
-          "random",
-          "random",
-          "random",
-          "random",
-          "random"
-        ),
-        Component = c(
-          "conditional",
-          "conditional",
-          "conditional",
-          "conditional",
-          "conditional",
-          "conditional",
-          "conditional",
-          "conditional",
-          "zero_inflated",
-          "zero_inflated",
-          "zero_inflated",
-          "zero_inflated",
-          "zero_inflated",
-          "zero_inflated",
-          "zero_inflated",
-          "zero_inflated"
-        ),
-        Group = c(
-          "",
-          "",
-          "",
-          "Intercept: persons",
-          "Intercept: persons",
-          "Intercept: persons",
-          "Intercept: persons",
-          "SD/Cor: persons",
-          "",
-          "",
-          "",
-          "Intercept: persons",
-          "Intercept: persons",
-          "Intercept: persons",
-          "Intercept: persons",
-          "SD/Cor: persons"
-        ),
-        Cleaned_Parameter = c(
-          "(Intercept)",
-          "child",
-          "camper",
-          "persons.1",
-          "persons.2",
-          "persons.3",
-          "persons.4",
-          "(Intercept)",
-          "(Intercept)",
-          "child",
-          "camper",
-          "persons.1",
-          "persons.2",
-          "persons.3",
-          "persons.4",
-          "(Intercept)"
-        )
+    list(
+      Parameter = c(
+        "b_Intercept", "b_child", "b_camper",
+        "r_persons[1,Intercept]", "r_persons[2,Intercept]", "r_persons[3,Intercept]",
+        "r_persons[4,Intercept]", "sd_persons__Intercept", "b_zi_Intercept",
+        "b_zi_child", "b_zi_camper", "r_persons__zi[1,Intercept]", "r_persons__zi[2,Intercept]",
+        "r_persons__zi[3,Intercept]", "r_persons__zi[4,Intercept]", "sd_persons__zi_Intercept"
       ),
-      class = c("clean_parameters", "data.frame"),
-      row.names = c(
-        NA,
-        -16L
+      Effects = c(
+        "fixed", "fixed", "fixed", "random", "random",
+        "random", "random", "random", "fixed", "fixed", "fixed", "random",
+        "random", "random", "random", "random"
+      ), Component = c(
+        "conditional",
+        "conditional", "conditional", "conditional", "conditional", "conditional",
+        "conditional", "conditional", "zi", "zi", "zi", "zi", "zi", "zi", "zi", "zi"
+      ),
+      Group = c(
+        "", "", "", "Intercept: persons",
+        "Intercept: persons", "Intercept: persons", "Intercept: persons",
+        "SD/Cor: persons", "", "", "", "Intercept: persons", "Intercept: persons",
+        "Intercept: persons", "Intercept: persons", "SD/Cor: persons"
+      ),
+      Cleaned_Parameter = c(
+        "(Intercept)", "child", "camper", "persons.1",
+        "persons.2", "persons.3", "persons.4", "(Intercept)", "(Intercept)",
+        "child", "camper", "persons.1", "persons.2", "persons.3", "persons.4",
+        "(Intercept)"
       )
     ),
     ignore_attr = TRUE
@@ -679,203 +611,62 @@ test_that("clean_parameters", {
 
   expect_equal(
     clean_parameters(m5),
-    structure(
-      list(
-        Parameter = c(
-          "b_count_Intercept",
-          "b_count_child",
-          "b_count_camper",
-          "b_count2_Intercept",
-          "b_count2_child",
-          "b_count2_livebait",
-          "r_persons__count[1,Intercept]",
-          "r_persons__count[2,Intercept]",
-          "r_persons__count[3,Intercept]",
-          "r_persons__count[4,Intercept]",
-          "sd_persons__count_Intercept",
-          "r_persons__count2[1,Intercept]",
-          "r_persons__count2[2,Intercept]",
-          "r_persons__count2[3,Intercept]",
-          "r_persons__count2[4,Intercept]",
-          "sd_persons__count2_Intercept",
-          "b_zi_count_Intercept",
-          "b_zi_count_camper",
-          "b_zi_count2_Intercept",
-          "b_zi_count2_child",
-          "r_persons__zi_count[1,Intercept]",
-          "r_persons__zi_count[2,Intercept]",
-          "r_persons__zi_count[3,Intercept]",
-          "r_persons__zi_count[4,Intercept]",
-          "sd_persons__zi_count_Intercept",
-          "r_persons__zi_count2[1,Intercept]",
-          "r_persons__zi_count2[2,Intercept]",
-          "r_persons__zi_count2[3,Intercept]",
-          "r_persons__zi_count2[4,Intercept]",
-          "sd_persons__zi_count2_Intercept"
-        ),
-        Effects = c(
-          "fixed",
-          "fixed",
-          "fixed",
-          "fixed",
-          "fixed",
-          "fixed",
-          "random",
-          "random",
-          "random",
-          "random",
-          "random",
-          "random",
-          "random",
-          "random",
-          "random",
-          "random",
-          "fixed",
-          "fixed",
-          "fixed",
-          "fixed",
-          "random",
-          "random",
-          "random",
-          "random",
-          "random",
-          "random",
-          "random",
-          "random",
-          "random",
-          "random"
-        ),
-        Component = c(
-          "conditional",
-          "conditional",
-          "conditional",
-          "conditional",
-          "conditional",
-          "conditional",
-          "conditional",
-          "conditional",
-          "conditional",
-          "conditional",
-          "conditional",
-          "conditional",
-          "conditional",
-          "conditional",
-          "conditional",
-          "conditional",
-          "zero_inflated",
-          "zero_inflated",
-          "zero_inflated",
-          "zero_inflated",
-          "zero_inflated",
-          "zero_inflated",
-          "zero_inflated",
-          "zero_inflated",
-          "zero_inflated",
-          "zero_inflated",
-          "zero_inflated",
-          "zero_inflated",
-          "zero_inflated",
-          "zero_inflated"
-        ),
-        Group = c(
-          "",
-          "",
-          "",
-          "",
-          "",
-          "",
-          "Intercept: persons",
-          "Intercept: persons",
-          "Intercept: persons",
-          "Intercept: persons",
-          "SD/Cor: persons",
-          "Intercept: persons2",
-          "Intercept: persons2",
-          "Intercept: persons2",
-          "Intercept: persons2",
-          "SD/Cor: persons",
-          "",
-          "",
-          "",
-          "",
-          "Intercept: persons",
-          "Intercept: persons",
-          "Intercept: persons",
-          "Intercept: persons",
-          "SD/Cor: persons",
-          "Intercept: persons2",
-          "Intercept: persons2",
-          "Intercept: persons2",
-          "Intercept: persons2",
-          "SD/Cor: persons"
-        ),
-        Response = c(
-          "count",
-          "count",
-          "count",
-          "count2",
-          "count2",
-          "count2",
-          "count",
-          "count",
-          "count",
-          "count",
-          "count",
-          "count2",
-          "count2",
-          "count2",
-          "count2",
-          "count2",
-          "count",
-          "count",
-          "count2",
-          "count2",
-          "count",
-          "count",
-          "count",
-          "count",
-          "count",
-          "count2",
-          "count2",
-          "count2",
-          "count2",
-          "count2"
-        ),
-        Cleaned_Parameter = c(
-          "(Intercept)",
-          "child",
-          "camper",
-          "(Intercept)",
-          "child",
-          "livebait",
-          "persons.1",
-          "persons.2",
-          "persons.3",
-          "persons.4",
-          "count_Intercept",
-          "persons2.1",
-          "persons2.2",
-          "persons2.3",
-          "persons2.4",
-          "count2_Intercept",
-          "(Intercept)",
-          "camper",
-          "(Intercept)",
-          "child",
-          "persons.1",
-          "persons.2",
-          "persons.3",
-          "persons.4",
-          "zi_count_Intercept",
-          "persons2.1",
-          "persons2.2",
-          "persons2.3",
-          "persons2.4",
-          "zi_count2_Intercept"
-        )
+    list(
+      Parameter = c(
+        "b_count_Intercept", "b_count_child",
+        "b_count_camper", "b_count2_Intercept", "b_count2_child", "b_count2_livebait",
+        "r_persons__count[1,Intercept]", "r_persons__count[2,Intercept]",
+        "r_persons__count[3,Intercept]", "r_persons__count[4,Intercept]",
+        "sd_persons__count_Intercept", "r_persons__count2[1,Intercept]",
+        "r_persons__count2[2,Intercept]", "r_persons__count2[3,Intercept]",
+        "r_persons__count2[4,Intercept]", "sd_persons__count2_Intercept",
+        "b_zi_count_Intercept", "b_zi_count_camper", "b_zi_count2_Intercept",
+        "b_zi_count2_child", "r_persons__zi_count[1,Intercept]", "r_persons__zi_count[2,Intercept]",
+        "r_persons__zi_count[3,Intercept]", "r_persons__zi_count[4,Intercept]",
+        "sd_persons__zi_count_Intercept", "r_persons__zi_count2[1,Intercept]",
+        "r_persons__zi_count2[2,Intercept]", "r_persons__zi_count2[3,Intercept]",
+        "r_persons__zi_count2[4,Intercept]", "sd_persons__zi_count2_Intercept"
       ),
-      class = c("clean_parameters", "data.frame"),
-      row.names = c(NA, -30L)
+      Effects = c(
+        "fixed", "fixed", "fixed", "fixed", "fixed", "fixed",
+        "random", "random", "random", "random", "random", "random", "random",
+        "random", "random", "random", "fixed", "fixed", "fixed", "fixed",
+        "random", "random", "random", "random", "random", "random", "random",
+        "random", "random", "random"
+      ),
+      Component = c(
+        "conditional", "conditional",
+        "conditional", "conditional", "conditional", "conditional", "conditional",
+        "conditional", "conditional", "conditional", "conditional", "conditional",
+        "conditional", "conditional", "conditional", "conditional", "zi", "zi",
+        "zi", "zi", "zi", "zi", "zi", "zi", "zi", "zi", "zi", "zi", "zi", "zi"
+      ),
+      Group = c(
+        "", "", "", "", "", "", "Intercept: persons",
+        "Intercept: persons", "Intercept: persons", "Intercept: persons",
+        "SD/Cor: persons", "Intercept: persons2", "Intercept: persons2",
+        "Intercept: persons2", "Intercept: persons2", "SD/Cor: persons",
+        "", "", "", "", "Intercept: persons", "Intercept: persons", "Intercept: persons",
+        "Intercept: persons", "SD/Cor: persons", "Intercept: persons2",
+        "Intercept: persons2", "Intercept: persons2", "Intercept: persons2",
+        "SD/Cor: persons"
+      ),
+      Response = c(
+        "count", "count", "count", "count2",
+        "count2", "count2", "count", "count", "count", "count", "count",
+        "count2", "count2", "count2", "count2", "count2", "count", "count",
+        "count2", "count2", "count", "count", "count", "count", "count",
+        "count2", "count2", "count2", "count2", "count2"
+      ),
+      Cleaned_Parameter = c(
+        "(Intercept)",
+        "child", "camper", "(Intercept)", "child", "livebait", "persons.1",
+        "persons.2", "persons.3", "persons.4", "(Intercept)", "persons2.1",
+        "persons2.2", "persons2.3", "persons2.4", "(Intercept)", "(Intercept)",
+        "camper", "(Intercept)", "child", "persons.1", "persons.2", "persons.3",
+        "persons.4", "(Intercept)", "persons2.1", "persons2.2", "persons2.3",
+        "persons2.4", "(Intercept)"
+      )
     ),
     ignore_attr = TRUE
   )
@@ -890,13 +681,13 @@ test_that("get_modelmatrix", {
   expect_identical(dim(out), c(32L, 2L))
 })
 
-test_that("get_modelmatrix", {
+test_that("find_variables, mo", {
   m10 <- suppressWarnings(insight::download_model("brms_lf_1"))
   expect_identical(
     find_variables(m10),
     list(
       response = "carb",
-      conditional = c("gear", "vs"), disc = c("disc", "cyl")
+      conditional = c("gear", "vs"), disc = "cyl"
     )
   )
 })
@@ -910,8 +701,8 @@ test_that("get_variance works", {
     list(
       var.fixed = 4.91103174480995,
       var.random = 22.4069708072874,
-      var.residual = 11.3506326649,
-      var.distribution = 11.3506326649,
+      var.residual = 10.9304525807216,
+      var.distribution = 10.9304525807216,
       var.dispersion = 0,
       var.intercept = c(cyl = 22.4069708072874)
     ),
@@ -921,3 +712,270 @@ test_that("get_variance works", {
   # make sure it's a matrix
   # expect_true(is.matrix(get_modelmatrix(null_model(mdl))))
 })
+
+
+# get variance
+test_that("get_variance aligns with get_sigma", {
+  skip_if_not_installed("lme4")
+  data(mtcars)
+  set.seed(123)
+  mdl <- suppressWarnings(insight::download_model("brms_mixed_9"))
+  VC <- lme4::VarCorr(mdl)
+  out1 <- VC$residual__$sd[1, 1]^2 # Residual variance
+  out2 <- get_variance(mdl)$var.residual
+  out3 <- get_sigma(mdl)^2
+  expect_equal(out1, out2, tolerance = 1e-3, ignore_attr = TRUE)
+  expect_equal(out1, out3, tolerance = 1e-3, ignore_attr = TRUE)
+  expect_equal(out2, out3, tolerance = 1e-3, ignore_attr = TRUE)
+})
+
+
+# get variance
+test_that("get_variance works when sigma is modeled", {
+  data(mtcars)
+  set.seed(123)
+  m <- insight::download_model("brms_sigma_1")
+  skip_if(is.null(m))
+  expect_message(
+    {
+      out <- get_variance(m)
+    },
+    regex = "modeled directly"
+  )
+  expect_equal(
+    out,
+    list(
+      var.fixed = 2.712739833628, var.random = 25.6254745619452,
+      var.dispersion = 0, var.intercept = c(cyl = 25.6254745619452)
+    ),
+    ignore_attr = TRUE,
+    tolerance = 1e-3
+  )
+})
+
+
+# distributional parameters
+test_that("brms dpars 1", {
+  model <- insight::download_model("brms_sigma_1")
+  skip_if(is.null(model))
+  expect_identical(
+    find_parameters(model),
+    list(
+      conditional = c("b_Intercept", "b_hp"),
+      random = c(
+        "r_cyl[4,Intercept]", "r_cyl[6,Intercept]",
+        "r_cyl[8,Intercept]", "sd_cyl__Intercept"
+      ),
+      sigma = c("b_sigma_Intercept", "b_sigma_cyl")
+    )
+  )
+  expect_equal(
+    find_formula(model),
+    list(conditional = mpg ~ hp, random = ~ 1 | cyl, sigma = ~cyl),
+    ignore_attr = TRUE
+  )
+  expect_identical(
+    find_predictors(model),
+    list(conditional = "hp", sigma = "cyl")
+  )
+})
+
+
+# distributional parameters
+test_that("brms dpars 2", {
+  model <- insight::download_model("brms_sigma_3")
+  skip_if(is.null(model))
+  expect_identical(
+    find_parameters(model),
+    list(
+      conditional = c("b_Intercept", "b_Petal.Width"),
+      random = c(
+        "r_Group[G1,Intercept]", "r_Group[G2,Intercept]", "r_Group[G3,Intercept]",
+        "r_Group[G1,Petal.Width]", "r_Group[G2,Petal.Width]",
+        "r_Group[G3,Petal.Width]", "sd_Group__Intercept", "sd_Group__Petal.Width",
+        "cor_Group__Intercept__Petal.Width"
+      ),
+      sigma = c("b_sigma_Intercept", "b_sigma_Petal.Width"),
+      sigma_random = c(
+        "r_Group__sigma[G1,Intercept]", "r_Group__sigma[G2,Intercept]",
+        "r_Group__sigma[G3,Intercept]", "r_Group__sigma[G1,Petal.Width]",
+        "r_Group__sigma[G2,Petal.Width]", "r_Group__sigma[G3,Petal.Width]",
+        "sd_Group__sigma_Intercept", "sd_Group__sigma_Petal.Width",
+        "cor_Group__sigma_Intercept__sigma_Petal.Width"
+      )
+    )
+  )
+  expect_equal(
+    find_formula(model),
+    list(
+      conditional = Sepal.Width ~ Petal.Width,
+      random = ~ Petal.Width | Group,
+      sigma = ~Petal.Width,
+      sigma_random = ~ Petal.Width | Group
+    ),
+    ignore_attr = TRUE
+  )
+  expect_identical(
+    find_predictors(model),
+    list(conditional = "Petal.Width", sigma = "Petal.Width")
+  )
+})
+
+
+# distributional parameters
+test_that("brms dpars 3", {
+  model <- insight::download_model("brms_chocomini_1")
+  skip_if(is.null(model))
+  expect_identical(
+    find_parameters(model),
+    list(
+      conditional = "b_Intercept",
+      random = c(
+        "r_Participant[S001,Intercept]",
+        "r_Participant[S002,Intercept]", "r_Participant[S003,Intercept]",
+        "r_Participant[S004,Intercept]", "r_Participant[S005,Intercept]",
+        "r_Participant[S006,Intercept]", "r_Participant[S007,Intercept]",
+        "r_Participant[S008,Intercept]", "r_Participant[S009,Intercept]",
+        "r_Participant[S010,Intercept]", "r_Participant[S011,Intercept]",
+        "r_Participant[S012,Intercept]", "r_Participant[S013,Intercept]",
+        "r_Participant[S014,Intercept]", "r_Participant[S015,Intercept]",
+        "r_Participant[S016,Intercept]", "r_Participant[S017,Intercept]",
+        "r_Participant[S018,Intercept]", "r_Participant[S019,Intercept]",
+        "r_Participant[S020,Intercept]", "sd_Participant__Intercept"
+      ),
+      delta = "b_delta_Intercept",
+      k = "b_k_Intercept",
+      phi = "b_phi_Intercept",
+      delta_random = c(
+        "r_Participant__delta[S001,Intercept]",
+        "r_Participant__delta[S002,Intercept]", "r_Participant__delta[S003,Intercept]",
+        "r_Participant__delta[S004,Intercept]", "r_Participant__delta[S005,Intercept]",
+        "r_Participant__delta[S006,Intercept]", "r_Participant__delta[S007,Intercept]",
+        "r_Participant__delta[S008,Intercept]", "r_Participant__delta[S009,Intercept]",
+        "r_Participant__delta[S010,Intercept]", "r_Participant__delta[S011,Intercept]",
+        "r_Participant__delta[S012,Intercept]", "r_Participant__delta[S013,Intercept]",
+        "r_Participant__delta[S014,Intercept]", "r_Participant__delta[S015,Intercept]",
+        "r_Participant__delta[S016,Intercept]", "r_Participant__delta[S017,Intercept]",
+        "r_Participant__delta[S018,Intercept]", "r_Participant__delta[S019,Intercept]",
+        "r_Participant__delta[S020,Intercept]", "sd_Participant__delta_Intercept"
+      ),
+      k_random = c(
+        "r_Participant__k[S001,Intercept]", "r_Participant__k[S002,Intercept]",
+        "r_Participant__k[S003,Intercept]", "r_Participant__k[S004,Intercept]",
+        "r_Participant__k[S005,Intercept]", "r_Participant__k[S006,Intercept]",
+        "r_Participant__k[S007,Intercept]", "r_Participant__k[S008,Intercept]",
+        "r_Participant__k[S009,Intercept]", "r_Participant__k[S010,Intercept]",
+        "r_Participant__k[S011,Intercept]", "r_Participant__k[S012,Intercept]",
+        "r_Participant__k[S013,Intercept]", "r_Participant__k[S014,Intercept]",
+        "r_Participant__k[S015,Intercept]", "r_Participant__k[S016,Intercept]",
+        "r_Participant__k[S017,Intercept]", "r_Participant__k[S018,Intercept]",
+        "r_Participant__k[S019,Intercept]", "r_Participant__k[S020,Intercept]",
+        "sd_Participant__k_Intercept"
+      )
+    )
+  )
+
+  expect_equal(
+    find_formula(model),
+    list(
+      conditional = Real ~ 0 + Intercept,
+      random = ~ 0 + Intercept | Participant,
+      delta = ~ 0 + Intercept,
+      phi = ~ 0 + Intercept,
+      k = ~ 0 + Intercept,
+      delta_random = ~ 0 + Intercept | Participant,
+      k_random = ~ 0 + Intercept | Participant
+    ),
+    ignore_attr = TRUE
+  )
+  expect_null(find_predictors(model))
+})
+
+
+test_that("brms dpars find_parameters_random", {
+  model <- insight::download_model("brms_chocomini_1")
+  skip_if(is.null(model))
+  out <- find_parameters(model, effects = "random", component = "all")
+  expect_named(out, c("random", "delta_random", "k_random"))
+  out <- get_parameters(model, effects = "random", component = "all", summary = TRUE)
+  expect_true(all(out$Effects == "random"))
+  out <- find_parameters(model, effects = "all", component = "all")
+  expect_named(
+    out,
+    c("conditional", "random", "delta", "k", "phi", "delta_random", "k_random")
+  )
+})
+
+
+test_that("brms dpars find_auxiliary", {
+  data(mtcars)
+  model <- insight::download_model("brms_chocomini_1")
+  skip_if(is.null(model))
+  out <- find_auxiliary(model)
+  expect_identical(out, c("delta", "phi", "k"))
+
+  expect_warning(get_auxiliary(model), regex = "No auxiliary")
+
+  out <- get_auxiliary(model, type = "all")
+  expect_identical(out$Parameter, c("b_delta_Intercept", "b_phi_Intercept", "b_k_Intercept"))
+
+  expect_warning(
+    find_auxiliary(lm(mpg ~ hp, data = mtcars)),
+    regex = "only works for"
+  )
+  expect_silent(find_auxiliary(lm(mpg ~ hp, data = mtcars), verbose = FALSE))
+  expect_null(find_auxiliary(lm(mpg ~ hp, data = mtcars), verbose = FALSE))
+})
+
+
+test_that("brms dpars find_auxiliary", {
+  model <- insight::download_model("brms_zoib_1")
+  skip_if(is.null(model))
+  out <- find_auxiliary(model)
+  expect_identical(out, c("phi", "zoi", "coi"))
+  out <- find_parameters(model, effects = "all", component = "all")
+  expect_identical(
+    out,
+    list(
+      conditional = "b_Intercept",
+      random = c(
+        "r_participant[S1,Intercept]",
+        "r_participant[S10,Intercept]", "r_participant[S2,Intercept]",
+        "r_participant[S3,Intercept]", "r_participant[S4,Intercept]",
+        "r_participant[S5,Intercept]", "r_participant[S6,Intercept]",
+        "r_participant[S7,Intercept]", "r_participant[S8,Intercept]",
+        "r_participant[S9,Intercept]", "sd_participant__Intercept"
+      ),
+      coi = "b_coi_Intercept",
+      phi = "b_phi_Intercept",
+      zoi = "b_zoi_Intercept",
+      coi_random = c(
+        "r_participant__coi[S1,Intercept]",
+        "r_participant__coi[S10,Intercept]", "r_participant__coi[S2,Intercept]",
+        "r_participant__coi[S3,Intercept]", "r_participant__coi[S4,Intercept]",
+        "r_participant__coi[S5,Intercept]", "r_participant__coi[S6,Intercept]",
+        "r_participant__coi[S7,Intercept]", "r_participant__coi[S8,Intercept]",
+        "r_participant__coi[S9,Intercept]", "sd_participant__coi_Intercept"
+      ),
+      phi_random = c(
+        "r_participant__phi[S1,Intercept]",
+        "r_participant__phi[S10,Intercept]", "r_participant__phi[S2,Intercept]",
+        "r_participant__phi[S3,Intercept]", "r_participant__phi[S4,Intercept]",
+        "r_participant__phi[S5,Intercept]", "r_participant__phi[S6,Intercept]",
+        "r_participant__phi[S7,Intercept]", "r_participant__phi[S8,Intercept]",
+        "r_participant__phi[S9,Intercept]", "sd_participant__phi_Intercept"
+      ),
+      zoi_random = c(
+        "r_participant__zoi[S1,Intercept]",
+        "r_participant__zoi[S10,Intercept]", "r_participant__zoi[S2,Intercept]",
+        "r_participant__zoi[S3,Intercept]", "r_participant__zoi[S4,Intercept]",
+        "r_participant__zoi[S5,Intercept]", "r_participant__zoi[S6,Intercept]",
+        "r_participant__zoi[S7,Intercept]", "r_participant__zoi[S8,Intercept]",
+        "r_participant__zoi[S9,Intercept]", "sd_participant__zoi_Intercept"
+      )
+    )
+  )
+  out <- clean_parameters(model)
+  expect_identical(dim(out), c(48L, 5L))
+  expect_identical(unique(out$Component), c("conditional", "coi", "phi", "zoi"))
+})
