@@ -116,7 +116,7 @@ test_that("export_table, table_width", {
   model2 <- lavaan::cfa(structure, data = HolzingerSwineford1939)
 
   out <- performance::compare_performance(model1, model2)
-  expect_snapshot(print(out, table_width = 50), variant = "windows")
+  expect_snapshot(print(out, ci_digits = 2, table_width = 50), variant = "windows")
 
   data(iris)
   lm1 <- lm(Sepal.Length ~ Species, data = iris)
@@ -125,7 +125,7 @@ test_that("export_table, table_width", {
   lm6 <- lm5 <- lm4 <- lm(Sepal.Length ~ Species * Petal.Length + Petal.Width, data = iris)
 
   tab <- parameters::compare_parameters(lm1, lm2, lm3, lm4, lm5, lm6)
-  expect_snapshot(print(tab, table_width = 80), variant = "windows")
+  expect_snapshot(print(tab, ci_digits = 2, table_width = 80), variant = "windows")
 })
 
 
@@ -143,7 +143,7 @@ test_that("export_table, table_width, no split", {
   model2 <- lavaan::cfa(structure, data = HolzingerSwineford1939)
 
   out <- performance::compare_performance(model1, model2)
-  expect_snapshot(print(out, table_width = Inf), variant = "windows")
+  expect_snapshot(print(out, ci_digits = 2, table_width = Inf), variant = "windows")
 
   data(iris)
   lm1 <- lm(Sepal.Length ~ Species, data = iris)
@@ -171,13 +171,12 @@ test_that("export_table, table_width, remove duplicated empty lines", {
   expect_snapshot(print(export_table(out, table_width = 60, empty_line = "-", sep = " | ", remove_duplicates = TRUE)))
   expect_snapshot(print(export_table(out, table_width = 60, empty_line = "-", cross = "+", remove_duplicates = TRUE)))
 
-  skip_if_not_installed("ggeffects")
-  data(efc, package = "ggeffects")
-  out <- datawizard::data_codebook(efc[, 1:4])
+  data(efc_insight, package = "insight")
+  out <- datawizard::data_codebook(efc_insight[, 1:4])
   out$.row_id <- NULL
   expect_snapshot(print(export_table(out, table_width = 60, remove_duplicates = TRUE, empty_line = "-", cross = "+")))
   expect_snapshot(print(export_table(out, table_width = 60, remove_duplicates = FALSE, empty_line = "-", cross = "+")))
-  out <- datawizard::data_codebook(efc[, 1:3])
+  out <- datawizard::data_codebook(efc_insight[, 1:3])
   out$.row_id <- NULL
   expect_snapshot(print(export_table(out, table_width = 60, remove_duplicates = TRUE, empty_line = "-", cross = "+")))
   expect_snapshot(print(export_table(out, table_width = 60, remove_duplicates = FALSE, empty_line = "-", cross = "+")))
@@ -255,3 +254,32 @@ test_that("export_table, gt, complex with group indention", {
   ))
   expect_snapshot(as.character(out))
 })
+
+test_that("export_table, new column names", {
+  data(iris)
+  x <- as.data.frame(iris[1:5, ])
+  out <- export_table(x, column_names = letters[1:5])
+  expect_identical(
+    strsplit(out, "\n")[[1]][1],
+    "   a |    b |    c |    d |      e"
+  )
+  out <- export_table(x, column_names = c(Species = "a"))
+  expect_identical(
+    strsplit(out, "\n")[[1]][1],
+    "Sepal.Length | Sepal.Width | Petal.Length | Petal.Width |      a"
+  )
+
+  # errors
+  expect_error(
+    export_table(x, column_names = letters[1:4]),
+    regex = "Number of names"
+  )
+  expect_error(
+    export_table(x, column_names = c(Species = "a", abc = "b")),
+    regex = "Not all names"
+  )
+  expect_error(
+    export_table(x, column_names = c(Species = "a", "b")),
+    regex = "is a named vector"
+  )
+})
