@@ -1,9 +1,8 @@
-m1 <- lm(hp ~ ordered(cyl), data = mtcars)
-m2 <- lm(hp ~ as.ordered(cyl), data = mtcars)
-m3 <- lm(hp ~ as.factor(cyl), data = mtcars)
-m4 <- lm(hp ~ factor(cyl), data = mtcars)
-
 test_that("get_datagrid - data from models", {
+  m1 <- lm(hp ~ ordered(cyl), data = mtcars)
+  m2 <- lm(hp ~ as.ordered(cyl), data = mtcars)
+  m3 <- lm(hp ~ as.factor(cyl), data = mtcars)
+  m4 <- lm(hp ~ factor(cyl), data = mtcars)
   expect_identical(get_datagrid(m1)$cyl, c(4, 6, 8))
   expect_identical(get_datagrid(m2)$cyl, c(4, 6, 8))
   expect_identical(get_datagrid(m3)$cyl, c(4, 6, 8))
@@ -18,37 +17,45 @@ test_that("get_datagrid - preserve factor levels #695", {
   expect_identical(levels(grid$cyl), c("4", "6", "8"))
 })
 
-m <- lm(Sepal.Width ~ Petal.Length + Petal.Width + Species, data = iris)
 # adjusted for works
 test_that("get_datagrid - adjusted for works", {
+  data(iris)
+  m <- lm(Sepal.Width ~ Petal.Length + Petal.Width + Species, data = iris)
   dg <- insight::get_datagrid(m, "Species")
   expect_identical(attributes(dg)$adjusted_for, c("Petal.Length", "Petal.Width"))
 })
 
 # bracket tokens
 test_that("get_datagrid - terciles, quartiles, mean-sd", {
+  data(iris)
+  m <- lm(Sepal.Width ~ Petal.Length + Petal.Width + Species, data = iris)
   dg <- insight::get_datagrid(m, "Petal.Width = [quartiles]")
-  expect_equal(dg$Petal.Width, unname(quantile(iris$Petal.Width)), tolerance = 1e-4)
+  expect_equal(dg$Petal.Width, unname(quantile(iris$Petal.Width)[2:4]), tolerance = 1e-4)
   expect_identical(attributes(dg)$adjusted_for, c("Petal.Length", "Species"))
 
   dg <- insight::get_datagrid(m, "Petal.Width = [meansd]")
   .center <- mean(iris$Petal.Width)
   .spread <- sd(iris$Petal.Width)
-  expect_equal(dg$Petal.Width, .center + c(-1, 0, 1) * .spread, tolerance = 1e-4)
+  expect_equal(dg$Petal.Width, round(.center + c(-1, 0, 1) * .spread, 3), tolerance = 1e-4)
   expect_identical(attributes(dg)$adjusted_for, c("Petal.Length", "Species"))
 
   dg <- insight::get_datagrid(m, "Petal.Width = [terciles]")
-  expect_equal(dg$Petal.Width, unname(quantile(iris$Petal.Width, probs = (0:3) / 3)), tolerance = 1e-4)
+  expect_equal(dg$Petal.Width, unname(round(quantile(iris$Petal.Width, probs = (1:2) / 3), 3)), tolerance = 1e-4)
   expect_identical(attributes(dg)$adjusted_for, c("Petal.Length", "Species"))
 
   dg <- insight::get_datagrid(m, "Petal.Width = [terciles2]")
-  expect_equal(dg$Petal.Width, unname(quantile(iris$Petal.Width, probs = (1:2) / 3)), tolerance = 1e-4)
+  expect_equal(dg$Petal.Width, unname(round(quantile(iris$Petal.Width, probs = (0:3) / 3), 3)), tolerance = 1e-4)
   expect_identical(attributes(dg)$adjusted_for, c("Petal.Length", "Species"))
 
   dg <- insight::get_datagrid(m, "Petal.Width = [fivenum]")
   expect_equal(dg$Petal.Width, unname(quantile(iris$Petal.Width)), tolerance = 1e-4)
   expect_identical(attributes(dg)$adjusted_for, c("Petal.Length", "Species"))
 
+  dg <- insight::get_datagrid(iris, by = "Petal.Width = [meansd]")
+  expect_equal(dg$Petal.Width, c(0.437, 1.199, 1.962), tolerance = 1e-5)
+  dg <- insight::get_datagrid(iris, by = "Petal.Width = [meansd]", digits = 1)
+  expect_equal(dg$Petal.Width, c(0.4, 1.2, 2.0), tolerance = 1e-5)
+
   set.seed(123)
   dg <- insight::get_datagrid(m, "Petal.Width = [sample 8]")
   set.seed(123)
@@ -75,27 +82,24 @@ test_that("get_datagrid - terciles, quartiles, mean-sd", {
     regex = "should either indicate"
   )
 
-  skip_if_not_installed("ggeffects")
   skip_if_not_installed("datawizard")
-  data(efc, package = "ggeffects")
-  efc$c161sex <- datawizard::to_factor(efc$c161sex)
-  efc$e16sex <- datawizard::to_factor(efc$e16sex)
-  model <- lm(neg_c_7 ~ barthtot + c160age * c161sex, data = efc)
+  data(efc_insight, package = "insight")
+  efc_insight$c161sex <- datawizard::to_factor(efc_insight$c161sex)
+  efc_insight$e16sex <- datawizard::to_factor(efc_insight$e16sex)
+  model <- lm(neg_c_7 ~ barthtot + c160age * c161sex, data = efc_insight)
   out <- insight::get_datagrid(model, by = c("c160age=[pretty]", "c161sex"))
   expect_identical(out$c160age, c(20, 40, 60, 80, 20, 40, 60, 80))
 })
 
 # bracket tokens
 test_that("get_datagrid - range = grid", {
+  data(iris)
+  m <- lm(Sepal.Width ~ Petal.Length + Petal.Width + Species, data = iris)
   dg <- insight::get_datagrid(m, "Petal.Width", range = "grid")
   expect_equal(
     dg$Petal.Width,
-    c(
-      `-4 SD` = -1.8496, `-3 SD` = -1.0874, `-2 SD` = -0.3251, `-1 SD` = 0.4371,
-      Mean = 1.1993, `+1 SD` = 1.9616, `+2 SD` = 2.7238, `+3 SD` = 3.486,
-      `+4 SD` = 4.2483, `+5 SD` = 5.0105
-    ),
-    tolerance = 1e-3
+    c(0.1, 0.367, 0.633, 0.9, 1.167, 1.433, 1.7, 1.967, 2.233, 2.5),
+    tolerance = 1e-2
   )
   expect_identical(attributes(dg)$adjusted_for, c("Petal.Length", "Species"))
 
@@ -115,6 +119,7 @@ test_that("get_datagrid - range = grid", {
 
 # order of columns
 test_that("get_datagrid - column order", {
+  data(iris)
   m <- lm(Sepal.Width ~ Petal.Length + Petal.Width * Species, data = iris)
   dg <- insight::get_datagrid(m, c("Petal.Width", "Species"))
   expect_identical(colnames(dg), c("Petal.Width", "Species", "Petal.Length"))
@@ -125,6 +130,7 @@ test_that("get_datagrid - column order", {
 
 # list-argument
 test_that("get_datagrid - list-argument", {
+  data(iris)
   by <- list(Sepal.Length = c(3, 5), Species = c("versicolor", "virginica"))
   dg1 <- get_datagrid(iris, by = by)
   by <- c("Sepal.Length = c(3, 5)", "Species = c('versicolor', 'virginica')")
@@ -136,6 +142,7 @@ test_that("get_datagrid - list-argument", {
 
 test_that("get_datagrid - data", {
   skip_if_not_installed("bayestestR")
+  data(iris)
 
   # Factors
   expect_length(get_datagrid(iris$Species), 3)
@@ -150,17 +157,21 @@ test_that("get_datagrid - data", {
   expect_length(get_datagrid(x = iris$Sepal.Length), 10)
   expect_length(get_datagrid(x = iris$Sepal.Length, length = 5), 5)
   expect_length(get_datagrid(x = iris$Sepal.Length, length = NA), length(unique(iris$Sepal.Length)))
-  expect_identical(min(get_datagrid(x = iris$Sepal.Length, range = "iqr")), as.numeric(quantile(iris$Sepal.Length, 0.025))) # nolint
-  expect_identical(min(get_datagrid(x = iris$Sepal.Length, range = "hdi")), as.numeric(bayestestR::hdi(iris$Sepal.Length, ci = 0.95, verbose = FALSE))[2]) # nolint
-  expect_identical(min(get_datagrid(x = iris$Sepal.Length, range = "eti")), as.numeric(bayestestR::eti(iris$Sepal.Length, ci = 0.95, verbose = FALSE))[2]) # nolint
+  expect_identical(min(get_datagrid(x = iris$Sepal.Length, range = "iqr", digits = 15)), as.numeric(quantile(iris$Sepal.Length, 0.025))) # nolint
+  expect_identical(min(get_datagrid(x = iris$Sepal.Length, range = "hdi", digits = 15)), as.numeric(bayestestR::hdi(iris$Sepal.Length, ci = 0.95, verbose = FALSE))[2]) # nolint
+  expect_identical(min(get_datagrid(x = iris$Sepal.Length, range = "eti", digits = 15)), as.numeric(bayestestR::eti(iris$Sepal.Length, ci = 0.95, verbose = FALSE))[2]) # nolint
   expect_length(get_datagrid(iris$Sepal.Length, by = "c(1, 3, 4)"), 3)
   expect_length(get_datagrid(iris$Sepal.Length, by = "A = c(1, 3, 4)"), 3)
   expect_length(get_datagrid(iris$Sepal.Length, by = "[1, 3, 4]"), 3)
-  expect_length(get_datagrid(iris$Sepal.Length, by = "[1, 4]"), 10)
+  expect_length(get_datagrid(iris$Sepal.Length, by = "[1:4]"), 10)
+  expect_length(get_datagrid(iris$Sepal.Length, by = "[1,4]"), 2)
   expect_length(get_datagrid(iris$Sepal.Length, range = "sd", length = 10), 10)
-  expect_identical(as.numeric(get_datagrid(iris$Sepal.Length, range = "sd", length = 3)[2]), mean(iris$Sepal.Length))
+  expect_identical(as.numeric(get_datagrid(iris$Sepal.Length, range = "sd", length = 3)[2]), round(mean(iris$Sepal.Length), 3))
   expect_identical(as.numeric(get_datagrid(iris$Sepal.Length, range = "mad", length = 4)[2]), median(iris$Sepal.Length))
 
+  # interaction of variables
+  expect_identical(dim(get_datagrid(iris, "Species*Petal.Length")), c(30L, 5L))
+
   # Dataframes
   expect_identical(nrow(get_datagrid(iris, length = 2)), 48L)
   expect_identical(nrow(get_datagrid(iris, by = "Species", length = 2, numerics = 0)), 3L)
@@ -177,6 +188,12 @@ test_that("get_datagrid - data", {
     X = c("A", "A", "B"),
     Y = c(1, 5, 2),
     stringsAsFactors = FALSE
+  ), by = "Y", factors = "mode", length = 5)), 3L)
+
+  expect_identical(nrow(get_datagrid(data.frame(
+    X = c("A", "A", "B"),
+    Y = c(1.2, 5.5, 2),
+    stringsAsFactors = FALSE
   ), by = "Y", factors = "mode", length = 5)), 5L)
 
   expect_identical(nrow(get_datagrid(iris, by = c("Sepal.Length = 3", "Species"))), 3L)
@@ -253,6 +270,7 @@ test_that("get_datagrid - models", {
   expect_identical(dim(get_datagrid(mod, include_random = FALSE, include_smooth = FALSE)), as.integer(c(10, 1)))
 })
 
+
 test_that("get_datagrid - emmeans", {
   skip_if_not_installed("emmeans")
 
@@ -298,6 +316,7 @@ test_that("get_datagrid - emmeans", {
   expect_true(all(hp_vals %in% res[["hp"]]))
 })
 
+
 test_that("get_datagrid - marginaleffects", {
   skip_if_not_installed("marginaleffects")
 
@@ -339,6 +358,7 @@ test_that("get_datagrid - marginaleffects", {
   expect_true(all(c("contrast_hp", "contrast_wt") %in% colnames(res)))
 })
 
+
 test_that("get_datagrid - factor levels as reference / non-focal terms works", {
   d <- structure(list(
     lfp = structure(c(
@@ -403,6 +423,7 @@ test_that("get_datagrid - factor levels as reference / non-focal terms works", {
     by = "k618", range = "grid", preserve_range = FALSE,
     verbose = FALSE, include_response = TRUE
   )
+  expect_identical(dim(grid), c(4L, 5L))
   expect_identical(
     sapply(grid, class),
     c(
@@ -486,4 +507,182 @@ test_that("get_datagrid - informative error when by not found", {
     insight::get_datagrid(m, by = list(Sepal.Something = c(10, 40, 50))),
     regex = "was not found"
   )
+  expect_error(
+    insight::get_datagrid(m, by = "Sepal.Something"),
+    regex = "was not found"
+  )
+})
+
+
+test_that("get_datagrid - include weights", {
+  skip_if_not_installed("glmmTMB")
+  skip_if_not_installed("lme4")
+
+  data(sleepstudy, package = "lme4")
+  set.seed(123)
+  sleepstudy$wei_factor <- abs(rnorm(nrow(sleepstudy), 1, 0.4))
+
+  m <- glmmTMB::glmmTMB(Reaction ~ Days + (1 | Subject), data = sleepstudy, weights = wei_factor)
+  d <- insight::get_datagrid(m, "Days")
+  expect_named(d, c("Days", "Subject", "wei_factor"))
+
+  m <- glmmTMB::glmmTMB(Reaction ~ Days + (1 | Subject), data = sleepstudy)
+  d <- insight::get_datagrid(m, "Days")
+  expect_named(d, c("Days", "Subject"))
+})
+
+
+test_that("get_datagrid - correctly handle multiple numerics for grid and range", {
+  data(mtcars)
+  # range of length 10 for both
+  out <- get_datagrid(mtcars, c("mpg", "hp"), range = "range") # 10x10
+  expect_identical(dim(out), c(100L, 11L))
+  # grid creates range for first focal term and uses SD for remaining
+  out <- get_datagrid(mtcars, c("mpg", "hp"), range = "grid") # 10x3
+  expect_identical(dim(out), c(30L, 11L))
+})
+
+
+test_that("get_datagrid - handle integers", {
+  d <- data.frame(
+    x = 1:8,
+    y = letters[1:8]
+  )
+  expect_identical(dim(get_datagrid(d)), c(64L, 2L)) # 8^2
+  expect_identical(dim(get_datagrid(d, protect_integers = FALSE)), c(80L, 2L)) # 8 * length
+  expect_identical(dim(get_datagrid(d, range = "grid")), c(64L, 2L))
+  expect_identical(dim(get_datagrid(d, length = 5)), c(40L, 2L))
+
+  d <- data.frame(
+    x = 1:8,
+    y = 21:28,
+    z = letters[1:8]
+  )
+  expect_identical(dim(get_datagrid(d)), c(512L, 3L)) # 8^3
+  expect_identical(dim(get_datagrid(d, range = "grid")), c(192L, 3L)) # 8 * 3 * 8
+  expect_identical(dim(get_datagrid(d, length = 5)), c(200L, 3L))
+  expect_identical(dim(get_datagrid(d, length = 5, range = "grid")), c(120L, 3L))
+})
+
+
+test_that("get_datagrid - names for length and range", {
+  data(mtcars)
+  out <- get_datagrid(mtcars[1:4], by = c("hp", "mpg"))
+  expect_identical(dim(out), c(100L, 4L)) # 10x10 = 100, length is 10 by default
+  out <- get_datagrid(mtcars[1:4], by = c("hp", "mpg"), length = 2)
+  expect_identical(dim(out), c(4L, 4L))
+  out <- get_datagrid(mtcars[1:4], by = c("hp", "mpg"), length = c(mpg = 2, hp = 3))
+  expect_identical(dim(out), c(6L, 4L))
+  expect_identical(n_unique(out$hp), 3L)
+  out <- get_datagrid(mtcars[1:4], by = c("hp", "mpg"), length = c(mpg = 3, hp = 2))
+  expect_identical(dim(out), c(6L, 4L))
+  expect_identical(n_unique(out$hp), 2L)
+  out <- get_datagrid(
+    mtcars[1:4],
+    by = c("hp", "mpg"),
+    range = c(mpg = "iqr", hp = "sd"),
+    length = c(mpg = 5, hp = 4)
+  )
+  expect_identical(dim(out), c(20L, 4L))
+  expect_identical(n_unique(out$hp), 4L)
+  # errors
+  expect_error(
+    get_datagrid(mtcars[1:4], by = c("hp", "mpg"), length = c(mpa = 3, hp = 2)),
+    regex = "Names of"
+  )
+  expect_error(
+    get_datagrid(mtcars[1:4], by = c("hp", "mpg"), range = c(mpa = "iqr", hp = "sd")),
+    regex = "Names of"
+  )
+})
+
+
+test_that("get_datagrid - colon for ranges, in combination with length", {
+  data(iris)
+  expect_error(
+    get_datagrid(
+      iris,
+      by = c("Sepal.Width=[1:5]", "Petal.Widht=[1:3]"),
+      length = c(Petal.Width = 3, Sepal.Width = 4)
+    ),
+    regex = "was not found in"
+  )
+
+  out <- get_datagrid(
+    iris,
+    by = c("Sepal.Width=[1:5]", "Petal.Width=[1:3]"),
+    length = c(Petal.Width = 3, Sepal.Width = 4)
+  )
+  expect_identical(dim(out), c(12L, 5L))
+  expect_identical(n_unique(out$Sepal.Width), 4L)
+  expect_identical(n_unique(out$Petal.Width), 3L)
+
+  out <- get_datagrid(
+    iris,
+    by = c("Sepal.Width=1:5", "Petal.Width=1:3"),
+    length = c(Petal.Width = 3, Sepal.Width = 4)
+  )
+  expect_identical(dim(out), c(15L, 5L))
+  expect_identical(
+    out$Sepal.Width,
+    c(1L, 2L, 3L, 4L, 5L, 1L, 2L, 3L, 4L, 5L, 1L, 2L, 3L, 4L, 5L)
+  )
+  expect_identical(
+    out$Petal.Width,
+    c(1L, 1L, 1L, 1L, 1L, 2L, 2L, 2L, 2L, 2L, 3L, 3L, 3L, 3L, 3L)
+  )
+
+  out <- get_datagrid(
+    iris,
+    by = c("Sepal.Width=1:5", "Petal.Width=1:3")
+  )
+  expect_identical(dim(out), c(15L, 5L))
+  expect_identical(
+    out$Sepal.Width,
+    c(1L, 2L, 3L, 4L, 5L, 1L, 2L, 3L, 4L, 5L, 1L, 2L, 3L, 4L, 5L)
+  )
+  expect_identical(
+    out$Petal.Width,
+    c(1L, 1L, 1L, 1L, 1L, 2L, 2L, 2L, 2L, 2L, 3L, 3L, 3L, 3L, 3L)
+  )
+
+  out <- get_datagrid(
+    iris,
+    by = list(Sepal.Width = 1:5, Petal.Width = 1:3)
+  )
+  expect_identical(dim(out), c(15L, 5L))
+  expect_identical(
+    as.numeric(out$Sepal.Width),
+    c(1, 2, 3, 4, 5, 1, 2, 3, 4, 5, 1, 2, 3, 4, 5)
+  )
+  expect_identical(
+    as.numeric(out$Petal.Width),
+    c(1, 1, 1, 1, 1, 2, 2, 2, 2, 2, 3, 3, 3, 3, 3)
+  )
+})
+
+
+skip_if_not_installed("withr")
+withr::with_environment(
+  new.env(),
+  test_that("get_datagrid - functions", {
+    data(iris)
+    fun <<- function(x) x^2
+    out <- get_datagrid(iris, by = "Sepal.Width = fun(2:5)")
+    expect_identical(out$Sepal.Width, c(4, 9, 16, 25))
+  })
+)
+
+
+test_that("get_datagrid - multivariate", {
+  skip_on_cran()
+  skip_if_not_installed("curl")
+  skip_if_offline()
+  skip_if_not_installed("httr2")
+  skip_if_not_installed("brms")
+
+  m <- insight::download_model("brms_mv_1")
+  skip_if(is.null(m))
+  out <- get_datagrid(m, "wt=3:5")
+  expect_identical(dim(out), c(3L, 2L))
 })
