@@ -36,6 +36,7 @@ test_that("get_predicted - lm", {
   expect_equal(max(abs(as.data.frame(ref$fit)$lwr - rez$CI_low)), 0, tolerance = 1e-10)
 
   # Bootstrap
+  skip_if_not_installed("boot")
   set.seed(333)
   ref <- predict(x, newdata = get_data(x), se.fit = TRUE, interval = "confidence")
   rez <- get_predicted(x, iterations = 600, ci = 0.95)
@@ -95,6 +96,7 @@ test_that("get_predicted - glm", {
   expect_equal(max(abs(ref$se.fit - rez$SE)), 0, tolerance = 1e-4)
 
   # Bootstrap
+  skip_if_not_installed("boot")
   set.seed(333)
   ref <- suppressWarnings(predict(x, se.fit = TRUE, type = "response"))
   rez <- suppressWarnings(summary(get_predicted(x, iterations = 800, verbose = FALSE, ci = 0.95)))
@@ -715,3 +717,33 @@ test_that("zero-inflation stuff works", {
   expect_equal(p2, p4, tolerance = 1e-1, ignore_attr = TRUE)
   expect_equal(p3, p4, tolerance = 1e-1, ignore_attr = TRUE)
 })
+
+
+test_that("get_predicted works with brms-Wiener", {
+  skip_if_not_installed("brms")
+  skip_if_not_installed("RWiener")
+  skip_if_not_installed("curl")
+  skip_if_offline()
+  skip_if_not_installed("httr2")
+
+  m <- download_model("m_ddm_1")
+  skip_if(is.null(m))
+  d <- get_data(m)[1:5, ]
+  out <- get_predicted(m, data = d, predict = "prediction", ci = 0.95, iterations = 3)
+  expect_identical(dim(as.data.frame(out)), c(10L, 11L))
+  expect_named(
+    as.data.frame(out),
+    c(
+      "Row", "Component", "rt", "response", "Predicted", "SE", "CI_low",
+      "CI_high", "iter_1", "iter_2", "iter_3"
+    )
+  )
+  expect_identical(
+    as.data.frame(out)$Component,
+    c(
+      "rt", "rt", "rt", "rt", "rt", "response", "response", "response",
+      "response", "response"
+    )
+  )
+  expect_true(model_info(m)$is_wiener)
+})
